package com.das.common.captcha;

import cn.hutool.captcha.CaptchaUtil;
import cn.hutool.captcha.CircleCaptcha;
import cn.hutool.core.util.StrUtil;
import com.das.common.constant.AdminConstant;
import com.das.common.utils.AdminRedisTemplate;

import java.awt.*;
import java.time.Duration;

/**
 * @author chenhaojie
 * @Description
 */
public class CaptchaUtils {

    private CaptchaUtils(){}

    /**
     * 检查验证码是否有效
     * @param uuid 唯一键值
     * @param codeAnswer 验证码答案
     * @param adminRedisTemplate redis工具类
     * @return 验证成功为 TRUE  验证失败为 FALSE
     */
    public static boolean checkVerificationCode(String uuid, String codeAnswer, AdminRedisTemplate adminRedisTemplate){
        String verifyKey = AdminConstant.CAPTCHA_CODE_KEY + uuid;
        String answer = adminRedisTemplate.get(verifyKey);
        return StrUtil.isNotEmpty(codeAnswer) && answer != null && answer.equalsIgnoreCase(codeAnswer);
    }

    /**
     * 获取Base64图片
     * @param captchaProperties 配置
     * @param uuid 唯一值
     * @return base64字符串图片
     */
    public static String getImageBase64Str(AdminRedisTemplate adminRedisTemplate,
                                           CaptchaProperties captchaProperties,String uuid){
        // 使用hutool工具包中的工具类生成图片验证码
        //参数：宽  高  验证码位数 干扰线数量
        CircleCaptcha circleCaptcha = CaptchaUtil.createCircleCaptcha(150, 48, 4, 20);
        //设置背景色
        circleCaptcha.setBackground(Color.LIGHT_GRAY);
        String codeValue = circleCaptcha.getCode();
        String imageBase64 = circleCaptcha.getImageBase64();
        String verifyKey = AdminConstant.CAPTCHA_CODE_KEY + uuid;
        adminRedisTemplate.setEx(verifyKey, codeValue, Duration.ofSeconds(captchaProperties.getExpire()));
        return imageBase64;
    }


}
