package com.das.common.interceptor;


import cn.hutool.core.io.IoUtil;
import cn.hutool.core.util.StrUtil;
import com.das.common.utils.AESUtil;
import jakarta.servlet.FilterChain;
import jakarta.servlet.ReadListener;
import jakarta.servlet.ServletException;
import jakarta.servlet.ServletInputStream;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletRequestWrapper;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.http.MediaType;
import org.springframework.web.filter.OncePerRequestFilter;

import java.io.BufferedReader;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.nio.charset.StandardCharsets;
import java.util.Collections;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Set;

import static com.das.common.constant.HeaderConstant.IV_ATTR_NAME;
import static com.das.common.constant.HeaderConstant.TOKEN_ATTR_NAME;
import static org.springframework.http.HttpMethod.POST;

public class DecryptingOncePerRequestFilter extends OncePerRequestFilter {

    final private String aesKey;
    public DecryptingOncePerRequestFilter(String aesKey) {
        this.aesKey = aesKey;
    }


    @Override
    protected void doFilterInternal(HttpServletRequest request, HttpServletResponse response, FilterChain filterChain)
            throws ServletException, IOException {

        String method = request.getMethod();
        String contentType = request.getContentType();

        //当前只对Post的Application/json请求进行拦截处理
        if (POST.matches(method) &&  StrUtil.isNotBlank(contentType) && contentType.contains(MediaType.APPLICATION_JSON_VALUE)) {
            String token = request.getHeader(TOKEN_ATTR_NAME);
            String iv = request.getHeader(IV_ATTR_NAME);
            //如果获取到token，则进行解密
            if (StrUtil.isNotBlank(token)){
                token = AESUtil.decrypt(aesKey, token, iv);
            }
            //如果读取到requestBody，则进行解密
            String bodyData = readRequestBody(request);
            if (StrUtil.isNotBlank(bodyData)) {
                bodyData = AESUtil.decrypt(aesKey, bodyData, iv);
                // 使用自定义的请求包装器替换原始请求
                filterChain.doFilter(new DecryptingHttpServletRequestWrapper(request, bodyData, token), response);
            }
        } else {
            filterChain.doFilter(request, response);
        }

    }

    private String readRequestBody(HttpServletRequest request) throws IOException {
        return IoUtil.read(request.getInputStream(), StandardCharsets.UTF_8);
    }


    // 自定义的请求包装器
    static class DecryptingHttpServletRequestWrapper extends HttpServletRequestWrapper {
        private final String bodyData;
        private final String token;

        public DecryptingHttpServletRequestWrapper(HttpServletRequest request, String bodyData, String token) {
            super(request);
            this.bodyData = bodyData;
            this.token = token;
        }


        @Override
        public ServletInputStream getInputStream() {
            final ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(bodyData.getBytes(StandardCharsets.UTF_8));
            return new ServletInputStream() {
                @Override
                public boolean isFinished() {
                    return false;
                }

                @Override
                public boolean isReady() {
                    return false;
                }

                @Override
                public void setReadListener(ReadListener listener) {

                }

                @Override
                public int read() {
                    return byteArrayInputStream.read();
                }
            };
        }

        @Override
        public BufferedReader getReader() {
            return new BufferedReader(new InputStreamReader(getInputStream()));
        }

        @Override
        public String getHeader(String name) {
            if (TOKEN_ATTR_NAME.equals(name)){
                return token;
            }
            return super.getHeader(name);
        }

        @Override
        public Enumeration<String> getHeaders(String name) {
            Set<String> set = new HashSet<>(8);
            if (TOKEN_ATTR_NAME.equals(name) && StrUtil.isNotBlank(token)){
                set.add(token);
            }
            Enumeration<String> e = super.getHeaders(name);
            while (e.hasMoreElements()) {
                String n = e.nextElement();
                set.add(n);
            }
            return Collections.enumeration(set);
        }

        @Override
        public Enumeration<String> getHeaderNames() {
            Set<String> set = new HashSet<>(8);
            Enumeration<String> e = super.getHeaderNames();
            while (e.hasMoreElements()) {
                String n = e.nextElement();
                set.add(n);
            }
            if (StrUtil.isNotBlank(token)){
                set.add(token);
            }
            return Collections.enumeration(set);
        }


    }

}


