package com.das.common.utils;

import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.http.HttpStatus;

import java.io.Serial;
import java.io.Serializable;
import java.util.List;

/**
 * 分页数据对象
 */

@Data
@NoArgsConstructor
public class PageDataInfo<T> implements Serializable {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 总记录数
     */
    private long total;

    /**
     * 列表数据
     */
    private List<T> rows;

    /**
     * 消息状态码
     */
    private int code;

    /**
     * 消息内容
     */
    private String msg;

    /**
     * 分页
     *
     * @param list  列表数据
     * @param total 总记录数
     */
    public PageDataInfo(List<T> list, long total) {
        this.rows = list;
        this.total = total;
    }

    public static <T> PageDataInfo<T> build(List<T> list, long total) {
        PageDataInfo<T> rspData = new PageDataInfo<>();
        rspData.setCode(HttpStatus.OK.value());
        rspData.setMsg("查询成功");
        rspData.setRows(list);
        rspData.setTotal(total);
        return rspData;
    }

    public static <T> PageDataInfo<T> build(List<T> list) {
        PageDataInfo<T> rspData = new PageDataInfo<>();
        rspData.setCode(HttpStatus.OK.value());
        rspData.setMsg("查询成功");
        rspData.setRows(list);
        rspData.setTotal(list.size());
        return rspData;
    }

    public static <T> PageDataInfo<T> build() {
        PageDataInfo<T> rspData = new PageDataInfo<>();
        rspData.setCode(HttpStatus.OK.value());
        rspData.setMsg("查询成功");
        return rspData;
    }

}
