package com.das.common.utils;

public class SnowFlakeGenerator {
    private static final long datacenterId = 0L;
    private static final long DATACENTER_ID_BITS = 6L;
    private static final long MAX_DATACENTER_ID = 63L;
    private static final long sequenceBits = 12L;
    private static final long SEQUENCE_MAX;
    private static final long TW_EPOCH = 1440000000000L;
    private final long datacenterIdShift;
    private final long timestampLeftShift;
    private volatile long lastTimestamp;
    private volatile long sequence;

    public SnowFlakeGenerator() {
        this.datacenterIdShift = sequenceBits;
        this.timestampLeftShift = sequenceBits + 6L;
        this.lastTimestamp = -1L;
        this.sequence = 0L;
        if (datacenterId > 63L || datacenterId < 0L) {
            throw new RuntimeException("datacenterId > MAX_DATACENTER_ID");
        }
    }

    public synchronized Long generateLongId() {
        long timestamp = System.currentTimeMillis();
        if (timestamp < this.lastTimestamp) {
            throw new RuntimeException("Clock moved backwards.  Refusing to generate id for " + (this.lastTimestamp - timestamp) + " milliseconds.");
        } else {
            if (this.lastTimestamp == timestamp) {
                this.sequence = (this.sequence + 1L) % SEQUENCE_MAX;
                if (this.sequence == 0L) {
                    timestamp = this.tilNextMillis(this.lastTimestamp);
                }
            } else {
                this.sequence = 0L;
            }

            this.lastTimestamp = timestamp;
            return timestamp - 1440000000000L << (int)this.timestampLeftShift | datacenterId << (int)this.datacenterIdShift | this.sequence;
        }
    }

    protected long tilNextMillis(long lastTimestamp) {
        long timestamp;
        for(timestamp = System.currentTimeMillis(); timestamp <= lastTimestamp; timestamp = System.currentTimeMillis()) {
        }

        return timestamp;
    }

    static {
        SEQUENCE_MAX = ~(-1L << (int)sequenceBits);
    }
}
