package com.das.modules.auth.controller;

import cn.hutool.core.util.IdUtil;
import com.das.common.captcha.CaptchaProperties;
import com.das.common.captcha.CaptchaUtils;
import com.das.common.captcha.CaptchaVO;
import com.das.common.result.R;
import com.das.common.utils.AdminRedisTemplate;
import com.das.modules.auth.domain.dto.ChangePasswordDto;
import com.das.modules.auth.domain.dto.LoginDto;
import com.das.modules.auth.domain.dto.RefreshTokenDto;
import com.das.modules.auth.domain.vo.LoginUserDetailsVo;
import com.das.modules.auth.domain.vo.LoginVo;
import com.das.modules.auth.service.LoginService;
import io.micrometer.common.util.StringUtils;
import jakarta.annotation.Resource;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


/**
 * @author chenhaojie
 * @Description 登录控制层
 */
@Slf4j
@RequestMapping("/api/auth")
@RestController
public class LoginController {
    @Resource
    private LoginService loginService;
    @Resource
    private CaptchaProperties captchaProperties;

    @Resource
    private AdminRedisTemplate adminRedisTemplate;

    /**
     * 登录接口
     * @return 退出结果提示信息
     */
    @PostMapping("/login")
    public R<LoginUserDetailsVo> login(@RequestBody LoginDto loginDto, HttpServletRequest request, HttpServletResponse response) {
        LoginUserDetailsVo loginInfo = loginService.login(loginDto,request, response);
        if (StringUtils.isNotEmpty(loginInfo.getMsg())){
            return R.fail(loginInfo.getMsg());
        }
        return R.success(loginInfo);

    }

    /**
     * 退出登录接口
     * @return 退出结果提示信息
     */
    @PostMapping("/logout")
    public R<?> logout(HttpServletRequest request) {
        loginService.logout(request);
        return R.success("退出成功");
    }

    @PostMapping("/captchaImage")
    public R<CaptchaVO> getCaptcha() {
        String uuid = IdUtil.fastSimpleUUID();
        String imageBase64Str = CaptchaUtils.getImageBase64Str(adminRedisTemplate, captchaProperties, uuid);
        CaptchaVO captchaVO = new CaptchaVO(uuid, imageBase64Str);
        return R.success(captchaVO);
    }

    @PostMapping("/refreshToken")
    public R<LoginVo> refreshToken(@RequestBody RefreshTokenDto refreshToken){
        LoginVo loginVO  = loginService.refreshToken(refreshToken);
        return R.success(loginVO);
    }

    @PostMapping("/changePassword")
    public R<?> changePassword(@RequestBody ChangePasswordDto changePasswordDto) {
        int result = loginService.changePassword(changePasswordDto);
        if (result < 0) {
            return R.fail("密码修改失败");
        }
        return R.success("密码修改成功");
    }

}
