package com.das.modules.auth.controller;

import cn.dev33.satoken.stp.StpUtil;
import com.das.common.config.SessionUtil;
import com.das.common.constant.SysAuthorityIds;
import com.das.common.result.R;
import com.das.common.utils.PageDataInfo;
import com.das.modules.auth.domain.dto.DeleteDto;
import com.das.modules.auth.domain.dto.SysMenuDto;
import com.das.modules.auth.domain.dto.SysMenuQueryDto;
import com.das.modules.auth.domain.vo.SysUserVo;
import com.das.modules.auth.entity.SysMenu;
import com.das.modules.auth.service.SysMenuService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author chenhaojie
 * @Description 菜单控制层
 */
@Slf4j
@RequestMapping("/api/menus")
@RestController
public class SysMenusController {
    @Autowired
    private SysMenuService sysMenuService;

    /**
     * 新增菜单接口
     * @return 结果提示信息
     */
    @PostMapping("/add")
    public R<?> createMenu(@RequestBody SysMenuDto sysMenuDto) {

        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_ADMIN.toString());
        if(!hasPermission){
            return R.fail("没有系统管理权限");
        }
        return R.success(sysMenuService.createMenu(sysMenuDto));
    }

    /**
     * 修改菜单接口
     * @return 结果提示信息
     */
    @PostMapping("/update")
    public R<?> updateMenu(@RequestBody SysMenuDto sysMenuDto) {
        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_ADMIN.toString());
        if(!hasPermission){
            return R.fail("没有系统管理权限");
        }

        sysMenuService.updateMenu(sysMenuDto);
        return R.success();
    }

    /**
     * 删除菜单接口
     * @return 结果提示信息
     */
    @PostMapping("/delete")
    public R<?> deleteMenu(@RequestBody DeleteDto deleteDto) {
        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_ADMIN.toString());
        if(!hasPermission){
            return R.fail("没有系统管理权限");
        }

        sysMenuService.deleteMenu(deleteDto);
        return R.success();
    }

    @PostMapping("/query")
    public PageDataInfo<SysMenu> queryMenuList(@RequestBody SysMenuQueryDto categoryBo) {
        return sysMenuService.queryMenuList(categoryBo);
    }


    /**
     * 获取所有的菜单
     * @return 返回菜单树
     */
    @PostMapping("/list")
    public R<?> queryAllMenuList(@RequestBody SysMenuQueryDto sysMenuQueryDto) {
        return R.success(sysMenuService.queryAllMenuList(sysMenuQueryDto));
    }


    /**
     * 获取登录账号权限菜单列表
     * @return 返回菜单列表
     */
    @PostMapping("/tree")
    public R<?> getRootMenuByCurrentUser() {
        SysUserVo currentUser = (SysUserVo) StpUtil.getTokenSession().get(SessionUtil.SESSION_USER_KEY);
        return R.success(sysMenuService.getRootMenuByCurrentUser(currentUser.getAuthorities()));
    }
}
