package com.das.modules.auth.controller;

import cn.dev33.satoken.stp.StpUtil;
import com.das.common.constant.SysAuthorityIds;
import com.das.common.result.R;
import com.das.common.utils.PageDataInfo;
import com.das.modules.auth.domain.dto.DeleteDto;
import com.das.modules.auth.domain.dto.SysOrgDto;
import com.das.modules.auth.domain.dto.SysOrgQueryDto;
import com.das.modules.auth.entity.SysOrg;
import com.das.modules.auth.service.SysOrgService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author chenhaojie
 * @Description 用户控制层
 */
@Slf4j
@RequestMapping("/api/org")
@RestController
public class SysOrgController {
    @Autowired
    private SysOrgService sysOrgService;

    /**
     * 新增菜单接口
     * @return 结果提示信息
     */
    @PostMapping("/add")
    public R<?> createOrg(@RequestBody SysOrgDto sysOrgDto) {
        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_ADMIN.toString());
        if(!hasPermission){
            return R.fail("没有系统管理权限");
        }

        return R.success(sysOrgService.createOrg(sysOrgDto));
    }

    /**
     * 修改菜单接口
     * @return 结果提示信息
     */
    @PostMapping("/update")
    public R<?> updateOrg(@RequestBody SysOrgDto sysOrgDto) {
        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_ADMIN.toString());
        if(!hasPermission){
            return R.fail("没有系统管理权限");
        }

        sysOrgService.updateOrg(sysOrgDto);
        return R.success();
    }

    /**
     * 删除菜单接口
     * @return 结果提示信息
     */
    @PostMapping("/delete")
    public R<?> deleteOrg(@RequestBody DeleteDto deleteDto) {
        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_ADMIN.toString());
        if(!hasPermission){
            return R.fail("没有系统管理权限");
        }

        sysOrgService.deleteOrg(deleteDto);
        return R.success();
    }

    @PostMapping("/query")
    public PageDataInfo<SysOrg> queryOrgList(@RequestBody SysOrgQueryDto sysOrgQueryDto) {
        return sysOrgService.queryOrgList(sysOrgQueryDto);
    }

    /**
     * 构建机构树结构
     * @return 返回机构树
     */
    @PostMapping("/list")
    public R<?>  queryAllOrgTree(@RequestBody SysOrgQueryDto sysOrgQueryDto) {
        return R.success(sysOrgService.queryAllOrgTree(sysOrgQueryDto));
    }
}
