package com.das.modules.auth.controller;

import cn.dev33.satoken.stp.StpUtil;
import com.das.common.constant.SysAuthorityIds;
import com.das.common.result.R;
import com.das.common.utils.PageDataInfo;
import com.das.modules.auth.domain.dto.DeleteDto;
import com.das.modules.auth.domain.dto.SysRoleDto;
import com.das.modules.auth.domain.dto.SysRoleQueryDto;
import com.das.modules.auth.domain.vo.SysRoleVo;
import com.das.modules.auth.service.SysRoleService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author chenhaojie
 * @Description 角色控制层
 */
@Slf4j
@RequestMapping("/api/role")
@RestController
public class SysRoleController {
    @Autowired
    private SysRoleService sysRoleService;


    /**
     * 新增菜单接口
     * @return 结果提示信息
     */
    @PostMapping("/add")
    public R<?> createRole(@RequestBody SysRoleDto sysRoleDto) {
        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_ADMIN.toString());
        if(!hasPermission){
            return R.fail("没有系统管理权限");
        }

        return R.success(sysRoleService.createRole(sysRoleDto));
    }

    /**
     * 修改菜单接口
     * @return 结果提示信息
     */
        @PostMapping("/update")
    public R<?> updateRole(@RequestBody SysRoleDto sysRoleDto) {
        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_ADMIN.toString());
        if(!hasPermission){
            return R.fail("没有系统管理权限");
        }

        return R.success(sysRoleService.updateRole(sysRoleDto));
    }

    /**
     * 删除菜单接口
     * @return 结果提示信息
     */
    @PostMapping("/delete")
    public R<?> deleteRole(@RequestBody DeleteDto deleteDto) {
        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_ADMIN.toString());
        if(!hasPermission){
            return R.fail("没有系统管理权限");
        }

        sysRoleService.deleteRole(deleteDto);
        return R.success();
    }

    @PostMapping("/query")
    public PageDataInfo<SysRoleVo> queryRoleList(@RequestBody SysRoleQueryDto sysRoleQueryDto) {
        return sysRoleService.queryRoleList(sysRoleQueryDto);
    }

    @PostMapping("/queryAuthorityById")
    public R<?> queryAuthorityById(@RequestBody SysRoleQueryDto sysRoleQueryDto) {
        return R.success(sysRoleService.queryAuthorityById(sysRoleQueryDto));
    }




}
