package com.das.modules.auth.controller;

import cn.dev33.satoken.stp.StpUtil;
import com.das.common.constant.SysAuthorityIds;
import com.das.common.result.R;
import com.das.common.utils.PageDataInfo;
import com.das.modules.auth.domain.dto.DeleteDto;
import com.das.modules.auth.domain.dto.SysUserDto;
import com.das.modules.auth.domain.dto.SysUserQueryDto;
import com.das.modules.auth.domain.vo.SysUserVo;
import com.das.modules.auth.service.SysUserService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author chenhaojie
 * @Description 用户控制层
 */
@Slf4j
@RequestMapping("/api/user")
@RestController
public class SysUserController {
    @Autowired
    private SysUserService sysUserService;

    /**
     * 新增菜单接口
     * @return 结果提示信息
     */
    @PostMapping("/add")
    public R<?> createUser(@RequestBody SysUserDto sysUserDto) {
        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_ADMIN.toString());
        if(!hasPermission){
            return R.fail("没有系统管理权限");
        }

        return R.success(sysUserService.createUser(sysUserDto));
    }

    /**
     * 修改菜单接口
     * @return 结果提示信息
     */
    @PostMapping("/update")
    public R<?> updateUser(@RequestBody SysUserDto sysUserDto) {
        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_ADMIN.toString());
        if(!hasPermission){
            return R.fail("没有系统管理权限");
        }

        sysUserService.updateUser(sysUserDto);
        return R.success();
    }

    /**
     * 删除菜单接口
     * @return 结果提示信息
     */
    @PostMapping("/delete")
    public R<?> deleteUser(@RequestBody DeleteDto deleteDto) {
        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_ADMIN.toString());
        if(!hasPermission){
            return R.fail("没有系统管理权限");
        }

        sysUserService.deleteUser(deleteDto);
        return R.success();
    }

    @PostMapping("/query")
    public PageDataInfo<SysUserVo> queryUserList(@RequestBody SysUserQueryDto sysUserQueryDto) {
        return sysUserService.queryUserList(sysUserQueryDto);
    }


    /**
     * 用户信息修改接口
     * @return 结果提示信息
     */
    @PostMapping("/updateById")
    public R<?> updateUserById(@RequestBody SysUserDto sysUserDto) {
        sysUserService.updateUserById(sysUserDto);
        return R.success();
    }
}
