package com.das.modules.auth.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.das.common.utils.BeanCopyUtils;
import com.das.common.utils.PageDataInfo;
import com.das.common.utils.PageQuery;
import com.das.common.utils.SequenceUtils;
import com.das.modules.auth.domain.dto.DeleteDto;
import com.das.modules.auth.domain.dto.SysMenuDto;
import com.das.modules.auth.domain.dto.SysMenuQueryDto;
import com.das.modules.auth.domain.vo.SysMenuVo;
import com.das.modules.auth.entity.SysMenu;
import com.das.modules.auth.mapper.SysMenuMapper;
import com.das.modules.auth.service.SysMenuService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Service
public class SysMenuServiceImpl implements SysMenuService {

    @Autowired
    SysMenuMapper sysMenuMapper;
    @Override
    public SysMenu createMenu(SysMenuDto sysMenuDto) {
        SysMenu sysMenu = new SysMenu();
        BeanCopyUtils.copy(sysMenuDto,sysMenu);
        sysMenu.setId(SequenceUtils.generateId());
        sysMenu.setRevision(1);
        sysMenu.setCreatedTime(new Date());
        sysMenu.setUpdatedTime(new Date());
        sysMenuMapper.insert(sysMenu);
        return sysMenu;
    }

    @Override
    public void updateMenu(SysMenuDto sysMenuDto) {
        SysMenu sysMenu = new SysMenu();
        BeanCopyUtils.copy(sysMenuDto,sysMenu);
        sysMenu.setUpdatedTime(new Date());
        sysMenuMapper.updateById(sysMenu);
    }

    @Override
    public void deleteMenu(DeleteDto deleteDto) {
        sysMenuMapper.deleteById(deleteDto.getId());
    }

    @Override
    public PageDataInfo<SysMenu> queryMenuList(SysMenuQueryDto sysMenuQueryDto) {
        PageQuery pageQuery = new PageQuery();
        pageQuery.setPageNum(sysMenuQueryDto.getPageNum());
        pageQuery.setPageSize(sysMenuQueryDto.getPageSize());
        if(sysMenuQueryDto.getParentMenuId() == null) {
            sysMenuQueryDto.setParentMenuId(0L);
        }
        IPage<SysMenu> iPage = sysMenuMapper.queryMenuList(pageQuery.build(), sysMenuQueryDto);
        return PageDataInfo.build(iPage.getRecords(), iPage.getTotal());
    }

    @Override
    public List<SysMenuVo> queryAllMenuList(SysMenuQueryDto sysMenuQueryDto) {
        if(sysMenuQueryDto.getParentMenuId() == null) {
            sysMenuQueryDto.setParentMenuId(0L);
        }
        return sysMenuMapper.queryAllMenuList(sysMenuQueryDto);
    }

    @Override
    public SysMenuVo getRootMenuByCurrentUser(List<Integer> authorities) {
        SysMenuVo root = sysMenuMapper.getRootMenu();
        //按权限过滤菜单
        filterTreeByPermissions(root,authorities);
        return root;
    }


    // 递归方法，根据权限列表筛选树节点
    private void filterTreeByPermissions(SysMenuVo node, List<Integer> permissions) {
        if (node == null || node.getChildren() == null) {
            return;
        }

        // 创建一个新的列表来存放筛选后的子节点
        List<SysMenuVo> filteredChildren = new ArrayList<>();

        // 遍历当前节点的所有子节点
        for (SysMenuVo child : node.getChildren()) {
            Integer needAuthorityId = child.getAuthorityId();
            if (needAuthorityId == null) {
                //如果菜单没有权限设置，则该菜单不需要过滤
                filterTreeByPermissions(child, permissions);
                filteredChildren.add(child);
            }else{
                // 检查子节点的权限是否在权限列表中
                if (permissions.contains(needAuthorityId)) {
                    // 如果在，则递归处理子节点的子节点
                    filterTreeByPermissions(child, permissions);
                    // 将子节点添加到筛选后的子节点列表中
                    filteredChildren.add(child);
                }
            }
        }

        // 将筛选后的子节点列表赋值给当前节点的子节点列表
        node.setChildren(filteredChildren);
    }

}
