package com.das.modules.auth.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.das.common.utils.BeanCopyUtils;
import com.das.common.utils.PageDataInfo;
import com.das.common.utils.PageQuery;
import com.das.common.utils.SequenceUtils;
import com.das.modules.auth.domain.dto.DeleteDto;
import com.das.modules.auth.domain.dto.SysOrgDto;
import com.das.modules.auth.domain.dto.SysOrgQueryDto;
import com.das.modules.auth.entity.SysOrg;
import com.das.modules.auth.mapper.SysOrgMapper;
import com.das.modules.auth.service.SysOrgService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

@Service
public class SysOrgServiceImpl implements SysOrgService {
    @Autowired
    SysOrgMapper sysOrgMapper;

    @Override
    public SysOrg createOrg(SysOrgDto sysOrgDto) {
        SysOrg sysOrg = new SysOrg();
        BeanCopyUtils.copy(sysOrgDto,sysOrg);
        sysOrg.setId(SequenceUtils.generateId());
        sysOrg.setRevision(1);
        sysOrg.setCreatedTime(new Date());
        sysOrg.setUpdatedTime(new Date());
        sysOrgMapper.insert(sysOrg);
        return sysOrg;
    }

    @Override
    public void updateOrg(SysOrgDto sysOrgDto) {
        SysOrg sysOrg = new SysOrg();
        BeanCopyUtils.copy(sysOrgDto,sysOrg);
        sysOrg.setUpdatedTime(new Date());
        sysOrgMapper.updateById(sysOrg);
    }

    @Override
    public void deleteOrg(DeleteDto deleteDto) {
        // 根据机构id查询是否有用户
        if(sysOrgMapper.queryOrgUserCount(deleteDto.getId()) > 0) {
            throw new RuntimeException("该机构下有用户，不能删除");
        }
        sysOrgMapper.deleteById(deleteDto.getId());
    }

    @Override
    public PageDataInfo<SysOrg> queryOrgList(SysOrgQueryDto sysOrgQueryDto) {
        PageQuery pageQuery = new PageQuery();
        pageQuery.setPageNum(sysOrgQueryDto.getPageNum());
        pageQuery.setPageSize(sysOrgQueryDto.getPageSize());
        IPage<SysOrg> iPage = sysOrgMapper.queryOrgList(pageQuery.build(), sysOrgQueryDto);
        return PageDataInfo.build(iPage.getRecords(), iPage.getTotal());
    }

    public List<SysOrg> queryAllOrgTree(SysOrgQueryDto sysOrgQueryDto) {
        if(sysOrgQueryDto.getParentOrgId() == null) {
            sysOrgQueryDto.setParentOrgId(0L);
        }

        return sysOrgMapper.queryAllOrgTree(sysOrgQueryDto.getParentOrgId());
    }

}
