package com.das.modules.auth.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.das.common.exceptions.ServiceException;
import com.das.common.utils.BeanCopyUtils;
import com.das.common.utils.PageDataInfo;
import com.das.common.utils.PageQuery;
import com.das.common.utils.SequenceUtils;
import com.das.modules.auth.domain.dto.DeleteDto;
import com.das.modules.auth.domain.dto.SysRoleDto;
import com.das.modules.auth.domain.dto.SysRoleQueryDto;
import com.das.modules.auth.domain.vo.SysRoleAuthVo;
import com.das.modules.auth.domain.vo.SysRoleVo;
import com.das.modules.auth.entity.SysRole;
import com.das.modules.auth.entity.SysRoleAuthority;
import com.das.modules.auth.mapper.SysAuthorityMapper;
import com.das.modules.auth.mapper.SysRoleAuthorityMapper;
import com.das.modules.auth.mapper.SysRoleMapper;
import com.das.modules.auth.service.SysRoleService;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Service
public class SysRoleServiceImpl implements SysRoleService {

    private static final ObjectMapper JSON_MAPPER = new ObjectMapper();

    @Autowired
    SysAuthorityMapper sysAuthorityMapper;

    @Autowired
    SysRoleAuthorityMapper sysRoleAuthorityMapper;

    @Autowired
    SysRoleMapper sysRoleMapper;

    @Override
    public SysRoleDto createRole(SysRoleDto sysRoleDto) {
        if (sysRoleDto.getRoleName() == null || sysRoleDto.getAuthList() == null || !StringUtils.hasText(sysRoleDto.getRoleCode())) {
            throw new ServiceException("非法调用，参数缺失");
        }
        //判断角色编码code是否存在
        long roleCount = sysRoleMapper.existRoleByRoleCode(sysRoleDto.getRoleCode());
        if (roleCount > 0) {
            throw new ServiceException(String.format("角色 %s 已存在", sysRoleDto.getRoleCode()));
        }

        SysRole sysRole = new SysRole();
        BeanCopyUtils.copy(sysRoleDto, sysRole);
        sysRole.setId(SequenceUtils.generateId());
        sysRole.setRevision(1);
        sysRole.setCreatedBy("测试");
        sysRole.setUpdatedBy("测试");
        sysRole.setCreatedTime(new Date());
        sysRole.setUpdatedTime(new Date());
        sysRoleMapper.insert(sysRole);

        //验证权限有效性
        String errorAuths = checkErrorAuthorities(sysRoleDto.getAuthList());
        if (StringUtils.hasText(errorAuths)) {
            throw new ServiceException("权限不存在 " + errorAuths);
        }
        if (sysRoleDto.getAuthList() != null) {
            //解锁role与auth绑定
            QueryWrapper<SysRoleAuthority> authorityInfoQueryWrapper = new QueryWrapper<>();
            authorityInfoQueryWrapper.eq("role_id", sysRoleDto.getId());
            sysRoleAuthorityMapper.delete(authorityInfoQueryWrapper);
            //绑定新权限
            for (Long authId : sysRoleDto.getAuthList()) {
                SysRoleAuthority roleAuthority = new SysRoleAuthority();
                roleAuthority.setRoleId(sysRole.getId());
                roleAuthority.setAuthorityId(authId);
                roleAuthority.setRevision(1);
                roleAuthority.setCreatedTime(new Date());
                roleAuthority.setUpdatedTime(new Date());
                sysRoleAuthorityMapper.insert(roleAuthority);
            }
        }
        return sysRoleDto;
    }

    private String checkErrorAuthorities(List<Long> auths) {
        if (auths != null && !auths.isEmpty()) {
            List<Long> errorAuthority = new ArrayList<>();
            for (Long authId : auths) {
                if (authId == null) {
                    continue;
                }
                long authCount = sysAuthorityMapper.existAuthority(authId);
                if (authCount == 0) {
                    errorAuthority.add(authId);
                }
            }
            if (!errorAuthority.isEmpty()) {
                try {
                    return JSON_MAPPER.writeValueAsString(errorAuthority);
                } catch (JsonProcessingException e) {
                    return null;
                }
            }
        }
        return null;
    }

    @Override
    public SysRoleDto updateRole(SysRoleDto sysRoleDto) {
        if (sysRoleDto.getId() == null) {
            throw new ServiceException("参数缺失");
        }
        SysRole sysRole = sysRoleMapper.selectById(sysRoleDto.getId());
        if (sysRole == null) {
            throw new ServiceException(String.format("角色 %s 不存在", sysRoleDto.getId()));
        }
        if (StringUtils.hasText(sysRoleDto.getRoleName())) {
            //若与数据库中角色名相同 则表示未对名称进行修改
            if (!sysRole.getRoleName().equals(sysRoleDto.getRoleName())) {
                //判断角色名是否存在
                long roleCount = sysRoleMapper.existRoleByName(sysRoleDto.getRoleName());
                if (roleCount > 0) {
                    throw new ServiceException(String.format("角色名 %s 已存在", sysRoleDto.getRoleName()));
                }
            }
        }

        // 更新角色自身
        sysRole.setRoleName(sysRoleDto.getRoleName());
        sysRole.setRoleCode(sysRoleDto.getRoleCode());
        sysRole.setId(sysRoleDto.getId());
        sysRole.setUpdatedTime(new Date());
        this.sysRoleMapper.updateById(sysRole);
        //验证权限有效性
        String errorAuths = checkErrorAuthorities(sysRoleDto.getAuthList());
        if (StringUtils.hasText(errorAuths)) {
            throw new ServiceException("权限不存在 " + errorAuths);
        }
        if (sysRoleDto.getAuthList() != null) {
            //解锁role与auth绑定
            QueryWrapper<SysRoleAuthority> authorityInfoQueryWrapper = new QueryWrapper<>();
            authorityInfoQueryWrapper.eq("role_id", sysRoleDto.getId());
            sysRoleAuthorityMapper.delete(authorityInfoQueryWrapper);
            //绑定新权限
            for (Long authId : sysRoleDto.getAuthList()) {
                SysRoleAuthority roleAuthority = new SysRoleAuthority();
                roleAuthority.setRoleId(sysRole.getId());
                roleAuthority.setAuthorityId(authId);
                roleAuthority.setRevision(1);
                roleAuthority.setCreatedTime(new Date());
                roleAuthority.setUpdatedTime(new Date());
                sysRoleAuthorityMapper.insert(roleAuthority);
            }
        }
        return sysRoleDto;
    }

    @Override
    public void deleteRole(DeleteDto deleteDto) {
        SysRole sysRole = sysRoleMapper.selectById(deleteDto.getId());
        if (deleteDto.getId()==null) {
            throw new ServiceException("参数缺失");
        }
        long roleCount = sysRoleMapper.existRoleByRoleCode(sysRole.getRoleCode());
        if (roleCount == 0) {
            throw new ServiceException("角色不存在");
        }
        //解锁role与Account绑定
        QueryWrapper<SysRole> accountRoleQueryWrapper = new QueryWrapper<>();
        accountRoleQueryWrapper.eq("id", deleteDto.getId());
        this.sysRoleMapper.delete(accountRoleQueryWrapper);
        //解除角色与权限绑定
        QueryWrapper<SysRoleAuthority> authorityInfoQueryWrapper = new QueryWrapper<>();
        authorityInfoQueryWrapper.eq("role_id", deleteDto.getId());
        sysRoleAuthorityMapper.delete(authorityInfoQueryWrapper);
        //删除角色
        sysRoleMapper.deleteById(deleteDto.getId());
    }

    @Override
    public PageDataInfo<SysRoleVo> queryRoleList(SysRoleQueryDto sysRoleQueryDto) {
        PageQuery pageQuery = new PageQuery();
        pageQuery.setPageNum(sysRoleQueryDto.getPageNum());
        pageQuery.setPageSize(sysRoleQueryDto.getPageSize());
        IPage<SysRoleVo> iPage = sysRoleMapper.queryRoleList(pageQuery.build(), sysRoleQueryDto);
        return PageDataInfo.build(iPage.getRecords(), iPage.getTotal());
    }

    @Override
    public List<SysRoleAuthVo> queryAuthorityById(SysRoleQueryDto sysRoleQueryDto) {
        return sysRoleMapper.queryAuthorityById(Long.valueOf(sysRoleQueryDto.getRoleId()));
    }
}
