package com.das.modules.auth.service.impl;

import cn.dev33.satoken.secure.BCrypt;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.das.common.exceptions.ServiceException;
import com.das.common.utils.BeanCopyUtils;
import com.das.common.utils.PageDataInfo;
import com.das.common.utils.PageQuery;
import com.das.common.utils.SequenceUtils;
import com.das.modules.auth.domain.dto.DeleteDto;
import com.das.modules.auth.domain.dto.SysUserDto;
import com.das.modules.auth.domain.dto.SysUserQueryDto;
import com.das.modules.auth.domain.vo.SysUserVo;
import com.das.modules.auth.entity.SysUser;
import com.das.modules.auth.entity.SysUserRole;
import com.das.modules.auth.mapper.SysRoleMapper;
import com.das.modules.auth.mapper.SysUserMapper;
import com.das.modules.auth.mapper.SysUserRoleMapper;
import com.das.modules.auth.service.SysUserService;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Service
public class SysUserServiceImpl implements SysUserService {

    private static final ObjectMapper JSON_MAPPER = new ObjectMapper();


    @Autowired
    SysUserMapper sysUserMapper;

    @Autowired
    SysRoleMapper sysRoleMapper;

    @Autowired
    SysUserRoleMapper sysUserRoleMapper;

    @Override
    public SysUserDto createUser(SysUserDto sysUserDto) {

        //根据账号account判断是否存在
        long roleCount = sysUserMapper.existUserByAccount(sysUserDto.getAccount());
        if (roleCount > 0) {
            throw new ServiceException(String.format("账号 %s 已存在", sysUserDto.getAccount()));
        }

        SysUser sysUser = new SysUser();
        BeanCopyUtils.copy(sysUserDto,sysUser);
        //密码加密
        String passwordEncode;
        if (!StringUtils.hasText(sysUserDto.getPassword())) {
            passwordEncode = BCrypt.hashpw("123456789", BCrypt.gensalt());
        } else {
            passwordEncode = BCrypt.hashpw(sysUserDto.getPassword(), BCrypt.gensalt());
        }
        sysUser.setId(SequenceUtils.generateId());
        sysUser.setRevision(1);
        sysUser.setCreatedTime(new Date());
        sysUser.setUpdatedTime(new Date());
        sysUser.setPassword(passwordEncode);
        sysUserMapper.insert(sysUser);

        if (sysUserDto.getRoleList() != null && !sysUserDto.getRoleList().isEmpty()) {
            //验证角色有效性
            String errorRoles = checkErrorRole(sysUserDto.getRoleList());
            if (StringUtils.hasText(errorRoles)) {
                throw new ServiceException("角色不存在 " + errorRoles);
            }
            //解锁role与Account绑定
            QueryWrapper<SysUserRole> accountRoleQueryWrapper = new QueryWrapper<>();
            accountRoleQueryWrapper.eq("user_id",sysUser.getId());
            sysUserRoleMapper.delete(accountRoleQueryWrapper);
            //绑定角色
            for (String srtRoleId : sysUserDto.getRoleList()) {
                long roleId = Long.getLong(srtRoleId);
                if (roleId == 0) {
                    continue;
                }
                SysUserRole accountRole = new SysUserRole();
                accountRole.setUserId(sysUser.getId());
                accountRole.setRoleId(roleId);
                accountRole.setRevision(1);
                accountRole.setCreatedTime(new Date());
                accountRole.setUpdatedTime(new Date());
                sysUserRoleMapper.insert(accountRole);
            }
        }
        // 消除密码
        sysUserDto.setPassword(null);
        return sysUserDto;
    }

    /**
     * 验证角色是否存在
     */
    private String checkErrorRole(List<String> roles) {
        if (roles != null && !roles.isEmpty()) {
            List<Long> errorRole = new ArrayList<>();
            for (String strRoleId : roles) {
                if (StringUtils.hasText(strRoleId)) {
                    long roleId=Long.getLong(strRoleId);
                    long roleCount = sysRoleMapper.existRoleByRoleId(roleId);
                    if (roleCount == 0) {
                        errorRole.add(roleId);
                    }
                }
            }
            if (!errorRole.isEmpty()) {
                try {
                    return JSON_MAPPER.writeValueAsString(errorRole);
                } catch (JsonProcessingException e) {
                    return null;
                }
            }
        }
        return null;
    }

    @Override
    public void updateUser(SysUserDto sysUserDto) {
        if (sysUserDto.getId() == null) {
            throw new ServiceException("参数缺失");
        }

        SysUser sysUser = sysUserMapper.selectById(sysUserDto.getId());
        if (sysUser == null) {
            throw new ServiceException(String.format("账号 %d 不存在", sysUserDto.getId()));
        }
        if (StringUtils.hasText(sysUserDto.getAccount())) {
            //若与数据库中账户名相同 则表示未对名称进行修改
            if (!sysUser.getAccount().equals(sysUserDto.getAccount())) {
                //判断账户名是否存在
                long userCount = sysUserMapper.existUserByAccount(sysUserDto.getAccount());
                if (userCount > 0) {
                    throw new ServiceException(String.format("账户名 %s 已存在", sysUserDto.getAccount()));
                }
            }
        }
        SysUser newSysUser = new SysUser();
        BeanUtils.copyProperties(sysUserDto, newSysUser);
        newSysUser.setUpdatedTime(new Date());
        sysUserMapper.updateById(newSysUser);

        if (sysUserDto.getRoleList() != null) {
            //验证角色有效性
            String errorRoles = checkErrorRole(sysUserDto.getRoleList());
            if (StringUtils.hasText(errorRoles)) {
                throw new ServiceException("角色不存在 " + errorRoles);
            }
            //解锁role与Account绑定
            QueryWrapper<SysUserRole> accountRoleQueryWrapper = new QueryWrapper<>();
            accountRoleQueryWrapper.eq("user_id",newSysUser.getId());
            sysUserRoleMapper.delete(accountRoleQueryWrapper);
            //绑定角色
            for (String strRoleId : sysUserDto.getRoleList()) {
                long roleId = Long.getLong(strRoleId);
                SysUserRole accountRole = new SysUserRole();
                accountRole.setUserId(sysUser.getId());
                accountRole.setRoleId(roleId);
                accountRole.setRevision(1);
                accountRole.setCreatedTime(new Date());
                accountRole.setUpdatedTime(new Date());
                sysUserRoleMapper.insert(accountRole);
            }
        }
    }

    @Override
    public void updateUserById(SysUserDto sysUserDto) {
        SysUser sysUser = new SysUser();
        if (sysUserDto.getId() == null) {
            throw new ServiceException("参数缺失");
        }
        SysUser oldSysUser = sysUserMapper.selectById(sysUserDto.getId());
        sysUser.setId(sysUserDto.getId());
        sysUser.setUpdatedTime(new Date());
        sysUser.setUserName(sysUserDto.getUserName());
        sysUser.setEmail(sysUserDto.getEmail());
        sysUser.setPhone(sysUserDto.getPhone());
        sysUser.setUpdatedBy(oldSysUser.getAccount());
        sysUser.setHeadImage(sysUserDto.getHeadImage());
        sysUserMapper.updateById(sysUser);
    }

    @Override
    public void deleteUser(DeleteDto deleteDto) {
        if (deleteDto.getId() ==null) {
            throw new ServiceException("参数缺失");
        }
        SysUser sysUser = sysUserMapper.selectById(deleteDto.getId());
        if (sysUser == null) {
            throw new ServiceException("账号不存在");
        }

        //解锁role与用户绑定
        QueryWrapper<SysUserRole> accountRoleQueryWrapper = new QueryWrapper<>();
        accountRoleQueryWrapper.eq("user_id", deleteDto.getId());
        this.sysUserRoleMapper.delete(accountRoleQueryWrapper);
        //删除角色
        sysUserMapper.deleteById(deleteDto.getId());
    }

    @Override
    public PageDataInfo<SysUserVo> queryUserList(SysUserQueryDto sysUserQueryDto) {
        PageQuery pageQuery = new PageQuery();
        pageQuery.setPageNum(sysUserQueryDto.getPageNum());
        pageQuery.setPageSize(sysUserQueryDto.getPageSize());
        IPage<SysUserVo> iPage = sysUserMapper.queryUserList(pageQuery.build(), sysUserQueryDto);
        return PageDataInfo.build(iPage.getRecords(), iPage.getTotal());
    }
}
