package com.das.modules.equipment.controller;

import cn.dev33.satoken.stp.StpUtil;
import com.das.common.constant.SysAuthorityIds;
import com.das.common.exceptions.ServiceException;
import com.das.common.result.R;
import com.das.modules.equipment.domain.dto.SysIotModelDto;
import com.das.modules.equipment.domain.dto.SysIotModelFieldDto;
import com.das.modules.equipment.domain.dto.SysIotModelServiceDto;
import com.das.modules.equipment.domain.vo.SysIotModelFieldVo;
import com.das.modules.equipment.domain.vo.SysIotModelServiceVo;
import com.das.modules.equipment.domain.vo.SysIotModelVo;
import com.das.modules.equipment.service.SysIotModelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 物模型Controller
 */
@RestController
@RequestMapping("/api/equipment/model")
public class SysIotModelController {

    @Autowired
    private SysIotModelService sysIotModelService;

    /** 新增物模型 */
    @PostMapping("/add")
    public R<SysIotModelVo> createSysIotModel(@RequestBody SysIotModelDto sysIotModelDto) {

        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_DEVICE_MGR.toString());
        if(!hasPermission){
            return R.fail("没有设备管理权限");
        }

        if (sysIotModelDto.getIotModelCode() == null ||  sysIotModelDto.getObjectType() == null ||  sysIotModelDto.getIotModelName() == null) {
            throw new ServiceException("参数缺失");
        }
        return R.success(sysIotModelService.creatSysIotModel(sysIotModelDto));
    }

    /** 修改物模型 */
    @PostMapping("/update")
    public R<SysIotModelVo> updateSysIotModel(@RequestBody SysIotModelDto sysIotModelDto) {

        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_DEVICE_MGR.toString());
        if(!hasPermission){
            return R.fail("没有设备管理权限");
        }

        if (sysIotModelDto.getIotModelCode() == null ||  sysIotModelDto.getObjectType() == null ||  sysIotModelDto.getIotModelName() == null) {
            throw new ServiceException("参数缺失");
        }
        return R.success(sysIotModelService.updateSysIotModel(sysIotModelDto));
    }


    /** 删除物模型 */
    @PostMapping("/delete")
    public R<Void> deleteSysIotModel(@RequestBody SysIotModelDto sysIotModelDto) {

        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_DEVICE_MGR.toString());
        if(!hasPermission){
            return R.fail("没有设备管理权限");
        }

        if (sysIotModelDto.getId() == null) {
            throw new ServiceException("参数缺失");
        }
        sysIotModelService.deleteSysIotModel(sysIotModelDto);
        return R.success();
    }

    /** 获取物模型列表 */
    @PostMapping("/list")
    public R<List<SysIotModelVo>> querySysIotModel(@RequestBody SysIotModelDto sysIotModelDto) {

        return R.success(sysIotModelService.querySysIotModel(sysIotModelDto));
    }


    /** 获取物模型属性列表 */
    @PostMapping("/attribute/list")
    public R<List<SysIotModelFieldVo>> querySysIotModelField(@RequestBody SysIotModelFieldDto sysIotModelFieldDto) {

        return R.success(sysIotModelService.querySysIotModelField(sysIotModelFieldDto));
    }


    /** 物模型属性新增 */
    @PostMapping("/attribute/add")
    public  R<SysIotModelFieldVo> addSysIotModelField(@RequestBody SysIotModelFieldDto sysIotModelFieldDto) {

        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_DEVICE_MGR.toString());
        if(!hasPermission){
            return R.fail("没有设备管理权限");
        }

        if (sysIotModelFieldDto.getIotModelId() == null ||  sysIotModelFieldDto.getAttributeCode() == null
                ||  sysIotModelFieldDto.getAttributeName() == null ||  sysIotModelFieldDto.getAttributeType() == null
                ||  sysIotModelFieldDto.getPorder() == null) {
            throw new ServiceException("参数缺失");
        }
        return R.success(sysIotModelService.creatSysIotModelField(sysIotModelFieldDto));
    }

    /** 物模型属性修改 */
    @PostMapping("/attribute/update")
    public  R<SysIotModelFieldVo> updateSysIotModelField(@RequestBody SysIotModelFieldDto sysIotModelFieldDto) {

        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_DEVICE_MGR.toString());
        if(!hasPermission){
            return R.fail("没有设备管理权限");
        }

        if (sysIotModelFieldDto.getIotModelId() == null ||  sysIotModelFieldDto.getAttributeCode() == null
                ||  sysIotModelFieldDto.getAttributeName() == null ||  sysIotModelFieldDto.getAttributeType() == null
                ||  sysIotModelFieldDto.getPorder() == null) {
            throw new ServiceException("参数缺失");
        }
        return R.success(sysIotModelService.updateSysIotModelField(sysIotModelFieldDto));
    }

    /** 物模型属性删除 */
    @PostMapping("/attribute/delete")
    public R<Void> deleteSysIotModelField(@RequestBody SysIotModelFieldDto sysIotModelFieldDto) {

        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_DEVICE_MGR.toString());
        if(!hasPermission){
            return R.fail("没有设备管理权限");
        }

        if (sysIotModelFieldDto.getId() == null) {
            throw new ServiceException("参数缺失");
        }
        sysIotModelService.deleteSysIotModelField(sysIotModelFieldDto);
        return R.success();
    }

    /** 获取物模型动作列表 */
    @PostMapping("/service/list")
    public R<List<SysIotModelServiceVo>> querySysIotModelField(@RequestBody SysIotModelServiceDto sysIotModelServiceDto) {

        return R.success(sysIotModelService.querySysIotModelService(sysIotModelServiceDto));
    }


    /** 新增物模型动作 */
    @PostMapping("/service/add")
    public  R<SysIotModelServiceVo> addSysIotModelService(@RequestBody SysIotModelServiceDto sysIotModelServiceDto) {

        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_DEVICE_MGR.toString());
        if(!hasPermission){
            return R.fail("没有设备管理权限");
        }

        if (sysIotModelServiceDto.getIotModelId() == null ||  sysIotModelServiceDto.getServiceCode() == null
                ||  sysIotModelServiceDto.getServiceName() == null ||  sysIotModelServiceDto.getServiceType() == null
                ||  sysIotModelServiceDto.getPorder() == null) {
            throw new ServiceException("参数缺失");
        }
        return R.success(sysIotModelService.creatSysIotModelService(sysIotModelServiceDto));
    }


    /** 物模型动作修改 */
    @PostMapping("/service/update")
    public  R<SysIotModelServiceVo> updateSysIotModelService(@RequestBody SysIotModelServiceDto sysIotModelServiceDto) {

        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_DEVICE_MGR.toString());
        if(!hasPermission){
            return R.fail("没有设备管理权限");
        }

        if (sysIotModelServiceDto.getIotModelId() == null ||  sysIotModelServiceDto.getServiceCode() == null
                ||  sysIotModelServiceDto.getServiceName() == null ||  sysIotModelServiceDto.getServiceType() == null
                ||  sysIotModelServiceDto.getPorder() == null) {
            throw new ServiceException("参数缺失");
        }
        return R.success(sysIotModelService.updateSysIotModelService(sysIotModelServiceDto));
    }

    /** 物模型属性删除 */
    @PostMapping("/service/delete")
    public R<Void> deleteSysIotModelService(@RequestBody SysIotModelServiceDto sysIotModelServiceDto) {

        //判断是否有权限
        boolean hasPermission = StpUtil.hasPermission(SysAuthorityIds.SYS_AUTHORITY_ID_DEVICE_MGR.toString());
        if(!hasPermission){
            return R.fail("没有设备管理权限");
        }

        if (sysIotModelServiceDto.getId() == null) {
            throw new ServiceException("参数缺失");
        }
        sysIotModelService.deleteSysIotModelService(sysIotModelServiceDto);
        return R.success();
    }
}

