package com.das.modules.equipment.service.impl;

import cn.dev33.satoken.stp.StpUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.das.common.config.SessionUtil;
import com.das.common.exceptions.ServiceException;
import com.das.common.utils.BeanCopyUtils;
import com.das.modules.auth.domain.vo.SysUserVo;
import com.das.modules.equipment.domain.dto.SysIotModelDto;
import com.das.modules.equipment.domain.dto.SysIotModelFieldDto;
import com.das.modules.equipment.domain.dto.SysIotModelServiceDto;
import com.das.modules.equipment.domain.vo.SysIotModelFieldVo;
import com.das.modules.equipment.domain.vo.SysIotModelServiceVo;
import com.das.modules.equipment.domain.vo.SysIotModelVo;
import com.das.modules.equipment.entity.SysIotModel;
import com.das.modules.equipment.entity.SysIotModelField;
import com.das.modules.equipment.entity.SysIotModelServices;
import com.das.modules.equipment.mapper.SysIotModelFieldMapper;
import com.das.modules.equipment.mapper.SysIotModelMapper;
import com.das.modules.equipment.mapper.SysIotModelServiceMapper;
import com.das.modules.equipment.service.SysIotModelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Transactional(rollbackFor = Exception.class)
@Service
public class SysIotModelServiceImpl implements SysIotModelService {

    @Autowired
    private SysIotModelMapper sysIotModelMapper;

    @Autowired
    private SysIotModelFieldMapper sysIotModelFieldMapper;

    @Autowired
    private SysIotModelServiceMapper sysIotModelServiceMapper;


    public SysIotModelVo creatSysIotModel(SysIotModelDto sysIotModelDto) {
        SysIotModel sysIotModel = new SysIotModel();
        BeanCopyUtils.copy(sysIotModelDto,sysIotModel);

        QueryWrapper<SysIotModel> sysIotModelQueryWrapper = new QueryWrapper<>();
        sysIotModelQueryWrapper.eq("iot_model_code", sysIotModelDto.getIotModelCode());
        SysIotModel sysIotModelQuery = sysIotModelMapper.selectOne(sysIotModelQueryWrapper);
        if (!(sysIotModelQuery == null)){
            throw new ServiceException("物模型code已经存在");
        }
        SysUserVo sysUserVo = (SysUserVo) StpUtil.getTokenSession().get(SessionUtil.SESSION_USER_KEY);
        sysIotModel.setCreatedTime(new Date());
        sysIotModel.setUpdatedTime(new Date());
        sysIotModel.setCreatedBy(sysUserVo.getAccount());
        sysIotModel.setUpdatedBy(sysUserVo.getAccount());

        sysIotModel.setRevision(1);
        sysIotModelMapper.insert(sysIotModel);
        SysIotModelVo sysIotModelVo = new SysIotModelVo();
        BeanCopyUtils.copy(sysIotModel,sysIotModelVo);
        return sysIotModelVo;
    }

    public SysIotModelVo updateSysIotModel(SysIotModelDto sysIotModelDto) {
        SysIotModel sysIotModel = new SysIotModel();
        BeanCopyUtils.copy(sysIotModelDto,sysIotModel);

        QueryWrapper<SysIotModel> sysIotModelQueryWrapper = new QueryWrapper<>();
        sysIotModelQueryWrapper.eq("iot_model_code", sysIotModelDto.getIotModelCode());
        SysIotModel sysIotModelQuery = sysIotModelMapper.selectOne(sysIotModelQueryWrapper);
        if (!(sysIotModelQuery == null)){
            throw new ServiceException("更新的物模型编码code重复");
        }
        SysUserVo sysUserVo = (SysUserVo) StpUtil.getTokenSession().get(SessionUtil.SESSION_USER_KEY);
        sysIotModel.setUpdatedTime(new Date());
        sysIotModel.setUpdatedBy(sysUserVo.getAccount());
//        sysIotModel.setUpdatedBy("sysUserVo.getAccount()");
        sysIotModelMapper.updateById(sysIotModel);
        SysIotModelVo sysIotModelVo = new SysIotModelVo();
        BeanCopyUtils.copy(sysIotModel,sysIotModelVo);
        return sysIotModelVo;
    }

    @Override
    public void deleteSysIotModel(SysIotModelDto sysIotModelDto) {
        sysIotModelMapper.deleteById(sysIotModelDto.getId());
        // 删除绑定的物模型属性和动作
        sysIotModelFieldMapper.delete(new QueryWrapper<SysIotModelField>().eq("iot_model_id",sysIotModelDto.getId()));
        sysIotModelServiceMapper.delete(new QueryWrapper<SysIotModelServices>().eq("iot_model_id",sysIotModelDto.getId()));
    }

    @Override
    public List<SysIotModelVo> querySysIotModel(SysIotModelDto sysIotModelDto) {
        List<SysIotModelVo> sysIotModelVoList = new ArrayList<>();
        List<SysIotModel> sysIotModels;
        if (sysIotModelDto.getIotModelCode() == null && sysIotModelDto.getIotModelName() == null){
            sysIotModels = sysIotModelMapper.selectList(null);
        } else {
            QueryWrapper<SysIotModel> sysIotModelQueryWrapper = new QueryWrapper<>();
            sysIotModelQueryWrapper.like("iot_model_code",sysIotModelDto.getIotModelCode()).or().like("iot_model_name",sysIotModelDto.getIotModelName());
            sysIotModels = sysIotModelMapper.selectList(sysIotModelQueryWrapper);
        }
        for (SysIotModel item : sysIotModels){
            SysIotModelVo sysIotModelVo = new SysIotModelVo();
            BeanCopyUtils.copy(item,sysIotModelVo);
            sysIotModelVoList.add(sysIotModelVo);
        }
        return sysIotModelVoList;
    }

    @Override
    public List<SysIotModelFieldVo> querySysIotModelField(SysIotModelFieldDto sysIotModelFieldDto) {
        List<SysIotModelFieldVo> sysIotModelFieldVoList = new ArrayList<>();
        QueryWrapper<SysIotModelField> sysIotModelFieldQueryWrapper = new QueryWrapper<>();
        sysIotModelFieldQueryWrapper.like("iot_model_id",sysIotModelFieldDto.getIotModelId());
        List<SysIotModelField> sysIotModelFields = sysIotModelFieldMapper.selectList(sysIotModelFieldQueryWrapper);
        for (SysIotModelField item : sysIotModelFields){
            SysIotModelFieldVo sysIotModelVo = new SysIotModelFieldVo();
            BeanCopyUtils.copy(item,sysIotModelVo);
            sysIotModelFieldVoList.add(sysIotModelVo);
        }
        return sysIotModelFieldVoList;
    }

    @Override
    public SysIotModelFieldVo creatSysIotModelField(SysIotModelFieldDto sysIotModelFieldDto) {
        SysIotModelField sysIotModelField = new SysIotModelField();
        BeanCopyUtils.copy(sysIotModelFieldDto,sysIotModelField);

        QueryWrapper<SysIotModelField> sysIotModelFieldQueryWrapper = new QueryWrapper<>();
        sysIotModelFieldQueryWrapper.eq("attribute_code", sysIotModelFieldDto.getAttributeCode());
        SysIotModelField sysIotModelFieldQuery = sysIotModelFieldMapper.selectOne(sysIotModelFieldQueryWrapper);
        if (!(sysIotModelFieldQuery == null)){
            throw new ServiceException("物模型属性code已经存在");
        }
        SysUserVo sysUserVo = (SysUserVo) StpUtil.getTokenSession().get(SessionUtil.SESSION_USER_KEY);
        sysIotModelField.setCreatedTime(new Date());
        sysIotModelField.setUpdatedTime(new Date());
        sysIotModelField.setCreatedBy(sysUserVo.getAccount());
        sysIotModelField.setUpdatedBy(sysUserVo.getAccount());

        sysIotModelField.setRevision(1);
        sysIotModelFieldMapper.insert(sysIotModelField);
        SysIotModelFieldVo sysIotModelFieldVo = new SysIotModelFieldVo();
        BeanCopyUtils.copy(sysIotModelField,sysIotModelFieldVo);
        return sysIotModelFieldVo;
    }

    @Override
    public SysIotModelFieldVo updateSysIotModelField(SysIotModelFieldDto sysIotModelFieldDto) {
        SysIotModelField sysIotModelField = new SysIotModelField();
        BeanCopyUtils.copy(sysIotModelFieldDto,sysIotModelField);

        QueryWrapper<SysIotModelField> sysIotModelFieldQueryWrapper = new QueryWrapper<>();
        sysIotModelFieldQueryWrapper.eq("attribute_code", sysIotModelFieldDto.getAttributeCode());
        SysIotModelField sysIotModelFieldQuery = sysIotModelFieldMapper.selectOne(sysIotModelFieldQueryWrapper);
        if (!(sysIotModelFieldQuery == null)){
            throw new ServiceException("物模型属性修改的code已经存在");
        }
        SysUserVo sysUserVo = (SysUserVo) StpUtil.getTokenSession().get(SessionUtil.SESSION_USER_KEY);
        sysIotModelField.setUpdatedTime(new Date());
        sysIotModelField.setUpdatedBy(sysUserVo.getAccount());
//        sysIotModelField.setUpdatedBy("sysUserVo.getAccount()");
        sysIotModelFieldMapper.updateById(sysIotModelField);
        SysIotModelFieldVo sysIotModelFieldVo = new SysIotModelFieldVo();
        BeanCopyUtils.copy(sysIotModelField,sysIotModelFieldVo);
        return sysIotModelFieldVo;
    }

    @Override
    public void deleteSysIotModelField(SysIotModelFieldDto sysIotModelFieldDto) {
        sysIotModelFieldMapper.deleteById(sysIotModelFieldDto.getId());
    }

    @Override
    public List<SysIotModelServiceVo> querySysIotModelService(SysIotModelServiceDto sysIotModelServiceDto) {
        List<SysIotModelServiceVo> sysIotModelServiceVoList = new ArrayList<>();
        QueryWrapper<SysIotModelServices> sysIotModelServicesQueryWrapper = new QueryWrapper<>();
        sysIotModelServicesQueryWrapper.like("iot_model_id",sysIotModelServiceDto.getIotModelId());
        List<SysIotModelServices> sysIotModelServices = sysIotModelServiceMapper.selectList(sysIotModelServicesQueryWrapper);
        for (SysIotModelServices item : sysIotModelServices){
            SysIotModelServiceVo sysIotServiceVo = new SysIotModelServiceVo();
            BeanCopyUtils.copy(item,sysIotServiceVo);
            sysIotModelServiceVoList.add(sysIotServiceVo);
        }
        return sysIotModelServiceVoList;
    }

    @Override
    public SysIotModelServiceVo creatSysIotModelService(SysIotModelServiceDto sysIotModelServiceDto) {
        SysIotModelServices sysIotModelServices = new SysIotModelServices();
        BeanCopyUtils.copy(sysIotModelServiceDto,sysIotModelServices);

        QueryWrapper<SysIotModelField> sysIotModelFieldQueryWrapper = new QueryWrapper<>();
        sysIotModelFieldQueryWrapper.eq("service_code", sysIotModelServiceDto.getServiceCode());
        SysIotModelField sysIotModelFieldQuery = sysIotModelFieldMapper.selectOne(sysIotModelFieldQueryWrapper);
        if (!(sysIotModelFieldQuery == null)){
            throw new ServiceException("物模型动作code已经存在");
        }
        SysUserVo sysUserVo = (SysUserVo) StpUtil.getTokenSession().get(SessionUtil.SESSION_USER_KEY);
        sysIotModelServices.setCreatedTime(new Date());
        sysIotModelServices.setUpdatedTime(new Date());
        sysIotModelServices.setCreatedBy(sysUserVo.getAccount());
        sysIotModelServices.setUpdatedBy(sysUserVo.getAccount());

        sysIotModelServices.setRevision(1);
        sysIotModelServiceMapper.insert(sysIotModelServices);
        SysIotModelServiceVo sysIotModelServiceVo = new SysIotModelServiceVo();
        BeanCopyUtils.copy(sysIotModelServices,sysIotModelServiceVo);
        return sysIotModelServiceVo;
    }

    @Override
    public SysIotModelServiceVo updateSysIotModelService(SysIotModelServiceDto sysIotModelServiceDto) {
        SysIotModelServices sysIotModelServices = new SysIotModelServices();
        BeanCopyUtils.copy(sysIotModelServiceDto,sysIotModelServices);

        QueryWrapper<SysIotModelField> sysIotModelFieldQueryWrapper = new QueryWrapper<>();
        sysIotModelFieldQueryWrapper.eq("service_code", sysIotModelServiceDto.getServiceCode());
        SysIotModelField sysIotModelFieldQuery = sysIotModelFieldMapper.selectOne(sysIotModelFieldQueryWrapper);
        if (!(sysIotModelFieldQuery == null)){
            throw new ServiceException("物模型动作更新code已经存在");
        }
        SysUserVo sysUserVo = (SysUserVo) StpUtil.getTokenSession().get(SessionUtil.SESSION_USER_KEY);
        sysIotModelServices.setUpdatedTime(new Date());
        sysIotModelServices.setUpdatedBy(sysUserVo.getAccount());
//        sysIotModelServices.setUpdatedBy("sysUserVo.getAccount()");
        sysIotModelServiceMapper.updateById(sysIotModelServices);
        SysIotModelServiceVo sysIotModelServiceVo = new SysIotModelServiceVo();
        BeanCopyUtils.copy(sysIotModelServices,sysIotModelServiceVo);
        return sysIotModelServiceVo;
    }

    @Override
    public void deleteSysIotModelService(SysIotModelServiceDto sysIotModelServiceDto) {
        sysIotModelServiceMapper.deleteById(sysIotModelServiceDto.getId());
    }

}
