# 设备相关模块

## API接口一览表

| 接口分类      | 接口描述                         | API接口                               | 权限                         |
| ------------- | -------------------------------- | ------------------------------------- | ---------------------------- |
| 2.1设备类型   | 2.1.1获取所有设备类型信息        | /api/equipment/type/list              |                              |
| 2.2物模型     | 2.2.1获取物模型列表              | /api/equipment/model/list             |                              |
|               | 2.2.2物模型新增                  | /api/equipment/model/add              | SYS_AUTHORITY_ID_ADMIN       |
|               | 2.2.3物模型修改                  | /api/equipment/model/update           | SYS_AUTHORITY_ID_ADMIN       |
|               | 2.2.4物模型删除                  | /api/equipment/model/delete           | SYS_AUTHORITY_ID_ADMIN       |
| 2.2物模型属性 | 2.2.5获取物模型属性列表          | /api/equipment/model/attribute/list   |                              |
|               | 2.2.6物模型属性新增              | /api/equipment/model/attribute/add    | SYS_AUTHORITY_ID_ADMIN       |
|               | 2.2.7物模型属性修改              | /api/equipment/model/attribute/update | SYS_AUTHORITY_ID_ADMIN       |
|               | 2.2.8物模型属性删除              | /api/equipment/model/attribute/delete | SYS_AUTHORITY_ID_ADMIN       |
| 2.2物模型方法 | 2.2.9获取物模型方法列表          | /api/equipment/model/service/list     |                              |
|               | 2.2.10物模型方法新增             | /api/equipment/model/service/add      | SYS_AUTHORITY_ID_ADMIN       |
|               | 2.2.11物模型方法修改             | /api/equipment/model/service/update   | SYS_AUTHORITY_ID_ADMIN       |
|               | 2.2.12物模型方法删除             | /api/equipment/model/service/delete   | SYS_AUTHORITY_ID_ADMIN       |
|               | 2.2.13 Excel导出物模型属性和方法 | /api/equipment/model/export           |                              |
|               | 2.2.14 Excel导入物模型属性和方法 | /api/equipment/model/import           | SYS_AUTHORITY_ID_ADMIN       |
| 2.3设备台账   | 2.3.1 设备不分页查询             | /api/equipment/list                   | SYS_AUTHORITY_ID_DEVICE_VIEW |
|               | 2.3.2 设备分页查询               | /api/equipment/query                  | SYS_AUTHORITY_ID_DEVICE_VIEW |
|               | 2.3.3 设备新增                   | /api/equipment/add                    | SYS_AUTHORITY_ID_DEVICE_MGR  |
|               | 2.3.4 设备修改                   | /api/equipment/update                 | SYS_AUTHORITY_ID_DEVICE_MGR  |
|               | 2.3.5 设备删除                   | /api/equipment/delete                 | SYS_AUTHORITY_ID_DEVICE_MGR  |
|               | 2.3.6 Excel导出设备清单          | /api/equipment/export                 | SYS_AUTHORITY_ID_DEVICE_VIEW |
|               | 2.3.7 Excel导入设备清单          | /api/equipment/import                 | SYS_AUTHORITY_ID_DEVICE_MGR  |

### 2.1 设备类型相关接口

#### 2.1.1 获取所有设备类型信息

POST 请求接口

> /api/equipment/type/list

请求参数

无

返回报文

```json
{
	"code": 200,
	"msg": "操作成功",
	"success": true,
	"data": [
		{
			"equipmentTypeId": "10001",
			"equipmentTypeName": "风电场"
		},
		{
			"equipmentTypeId": "10002",
			"equipmentTypeName": "机组"
		}
	]
}
```

### 2.2 物模型相关接口

#### 2.2.1 获取物模型列表
POST 请求接口

> /api/equipment/model/list

请求参数

```json
{
    "objectType":"10002",
    "iotModelName":"倍福机组",
    "iotModelCode":"beckhoff"    
}
```

入参描述

| 参数名       | 参数类型 | 可选 | 描述       |
| ------------ | -------- | ---- | ---------- |
| objectType   | String   | yes  | 设备类型ID |
| iotModelName | String   | yes  | 物模型名称 |
| iotModelCode | String   | yes  | 物模型编码 |

返回报文

```json
{
	"code": 200,
	"msg": "操作成功",
	"success": true,
	"data": [
		{
			"id": "123",
			"objectType": "10002",
			"iotModelCode": "beckhoff",
			"iotModelName": "倍福机组",
			"revision": 1,
			"createdBy": "admin",
			"createdTime": "2024-06-27 15:08:23",
			"updatedBy": "admin",
			"updatedTime": "2024-06-27 15:08:23"
		}
	]
}
```

注意： 按设备类型、物模型名称进行排序

#### 2.2.2物模型新增
POST 请求接口

> /api/equipment/model/add

请求参数

```json
{
    "objectType": "10002",
    "iotModelCode": "beckhoff",
    "iotModelName": "倍福机组",
    "revision": 1,
    "createdBy": "admin",
    "createdTime": "2024-06-27 15:08:23"
}
```

入参描述

| 参数名       | 参数类型 | 可选 | 描述       |
| ------------ | -------- | ---- | ---------- |
| objectType   | 字符串   | No   | 设备类型ID |
| iotModelCode | 字符串   | No   | 物模型编码 |
| iotModelName | 字符串   | No   | 物模型名称 |
| revision     | 数值     | No   | 乐观锁     |
| createdBy    | 字符串   | Yes  | 创建人     |
| createdTime  | 字符串   | Yes  | 创建时间   |

返回报文

```json
{
	"code": 200,
	"msg": "操作成功",
	"success": true,
	"data": [
		{
			"id": "123",
			"objectType": "10002",
			"iotModelCode": "beckhoff",
			"iotModelName": "倍福机组",
			"revision": 1,
			"createdBy": "admin",
			"createdTime": "2024-06-27 15:08:23",
			"updatedBy": "admin",
			"updatedTime": "2024-06-27 15:08:23"
		}
	]
}
```


#### 2.2.3物模型修改

POST 请求接口

> /api/equipment/model/update

请求参数

```json
{
    "id": "123",
    "objectType": "10002",
    "iotModelCode": "beckhoff",
    "iotModelName": "倍福机组",
    "revision": 1,
    "createdBy": "admin",
    "createdTime": "2024-06-27 15:08:23"
}
```

入参描述

| 参数名       | 参数类型 | 可选 | 描述       |
| ------------ | -------- | ---- | ---------- |
| id           | 字符串   | No   | 主键ID     |
| objectType   | 字符串   | No   | 设备类型ID |
| iotModelCode | 字符串   | No   | 物模型编码 |
| iotModelName | 字符串   | No   | 物模型名称 |
| revision     | 数值     | No   | 乐观锁     |
| updatedBy    | 字符串   | Yes  | 更新人     |
| updatedTime  | 字符串   | Yes  | 更新时间   |

返回报文

```json
{
	"code": 200,
	"msg": "更新成功",
	"success": true
}
```

#### 2.2.4物模型删除

POST 请求接口

> /api/equipment/model/delete

请求参数

```json
{
    "id": "123"
}
```

入参描述

| 参数名       | 参数类型 | 可选 | 描述       |
| ------------ | -------- | ---- | ---------- |
| id           | 字符串   | No   | 主键ID     |

返回报文

```json
{
	"code": 200,
	"msg": "删除成功",
	"success": true
}
```

#### 2.2.5获取物模型属性列表              

POST 请求接口
> /api/equipment/model/attribute/list 

请求参数

```json
{
    "iotModelId":"123"
}
```

入参描述

| 参数名     | 参数类型 | 可选 | 描述     |
| ---------- | -------- | ---- | -------- |
| iotModelId | String   | No   | 物模型ID |

返回报文

```json
{
	"code": 200,
	"msg": "操作成功",
	"success": true,
	"data": [
		{
			"id": "45678",
			"iotModelId": "123",
			"attributeCode": "grGenPowerForProcess",
			"attributeName": "发电机功率实时值",
            "attributeType":138,
            "porder":1,
			"revision": 1,
			"createdBy": "admin",
			"createdTime": "2024-06-27 15:08:23",
			"updatedBy": "admin",
			"updatedTime": "2024-06-27 15:08:23"
		}
	]
}
```

#### 2.2.6物模型属性新增 

POST 请求接口
> /api/equipment/model/attribute/add  

请求参数

```json
{
    "iotModelId": "123",
    "attributeCode": "grGenPowerForProcess",
    "attributeName": "发电机功率实时值",
    "attributeType":138,
    "porder":1,
    "revision": 1,
    "createdBy": "admin",
    "createdTime": "2024-06-27 15:08:23"
}
```

入参描述

| 参数名        | 参数类型 | 可选 | 描述                                 |
| ------------- | -------- | ---- | ------------------------------------ |
| iotModelId    | 字符串   | No   | 所属物模型ID                         |
| attributeCode | 字符串   | No   | 属性编码                             |
| attributeName | 字符串   | No   | 属性名称                             |
| attributeType | 数值     | No   | 属性类型 138模拟量139累积量140离散量 |
| porder        | 数值     | No   | 顺序号                               |
| revision      | 数值     | No   | 乐观锁                               |
| createdBy     | 字符串   | Yes  | 创建人                               |
| createdTime   | 字符串   | Yes  | 创建时间                             |

返回报文

```json
{
	"code": 200,
	"msg": "操作成功",
	"success": true,
	"data": [
		{
			"id": "45678",
            "iotModelId": "123",
            "attributeCode": "grGenPowerForProcess",
            "attributeName": "发电机功率实时值",
            "attributeType":138,
            "porder":1,
            "revision": 1,
            "createdBy": "admin",
            "createdTime": "2024-06-27 15:08:23",
            "updatedBy": "admin",
			"updatedTime": "2024-06-27 15:08:23"
		}
	]
}
```



#### 2.2.7物模型属性修改    

POST 请求接口
>/api/equipment/model/attribute/update 

请求参数

```json
{
    "id": "45678",
    "iotModelId": "123",
    "attributeCode": "grGenPowerForProcess",
    "attributeName": "发电机功率实时值",
    "attributeType":138,
    "porder":1,
    "revision": 1,
    "updatedBy": "admin",
    "updatedTime": "2024-06-27 15:08:23"
}
```

返回报文

```json
{
	"code": 200,
	"msg": "更新成功",
	"success": true
}
```



#### 2.2.8物模型属性删除              

POST 请求接口
 > /api/equipment/model/attribute/delete 

请求参数

```json
{
    "id": "45678"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述   |
| ------ | -------- | ---- | ------ |
| id     | 字符串   | No   | 主键ID |

返回报文

```json
{
	"code": 200,
	"msg": "删除成功",
	"success": true
}
```

#### 2.2.9获取物模型方法列表 

POST 请求接口
>/api/equipment/model/service/list     

请求参数

```json
{
    "iotModelId":"123"
}
```

入参描述

| 参数名     | 参数类型 | 可选 | 描述     |
| ---------- | -------- | ---- | -------- |
| iotModelId | String   | No   | 物模型ID |

返回报文

```json
{
	"code": 200,
	"msg": "操作成功",
	"success": true,
	"data": [
		{
			"id": "78901",
			"iotModelId": "123",
			"serviceCode": "grActivePowerSetPointValue",
			"serviceName": "功率设定值",
            "serviceType":146,
            "porder":1,
			"revision": 1,
			"createdBy": "admin",
			"createdTime": "2024-06-27 15:08:23",
			"updatedBy": "admin",
			"updatedTime": "2024-06-27 15:08:23"
		}
	]
}
```

#### 2.2.10物模型方法新增            

POST 请求接口
> /api/equipment/model/service/add      

请求参数

```json
{
    "iotModelId": "123",
    "serviceCode": "grActivePowerSetPointValue",
    "serviceName": "功率设定值",
    "serviceType":146,
    "porder":1,
    "revision": 1,
    "createdBy": "admin",
    "createdTime": "2024-06-27 15:08:23"
}
```

入参描述

| 参数名      | 参数类型 | 可选 | 描述                       |
| ----------- | -------- | ---- | -------------------------- |
| iotModelId  | 字符串   | No   | 所属物模型ID               |
| serviceCode | 字符串   | No   | 方法编码                   |
| serviceName | 字符串   | No   | 方法名称                   |
| serviceType | 数值     | No   | 属性类型 146 遥调 147 遥控 |
| porder      | 数值     | No   | 顺序号                     |
| revision    | 数值     | No   | 乐观锁                     |
| createdBy   | 字符串   | Yes  | 创建人                     |
| createdTime | 字符串   | Yes  | 创建时间                   |

返回报文

```json
{
	"code": 200,
	"msg": "操作成功",
	"success": true,
	"data": [
		{
			"id": "78901",
            "iotModelId": "123",
            "serviceCode": "grActivePowerSetPointValue",
            "serviceName": "功率设定值",
            "serviceType":146,
            "porder":1,
            "revision": 1,
            "createdBy": "admin",
            "createdTime": "2024-06-27 15:08:23",
            "updatedBy": "admin",
			"updatedTime": "2024-06-27 15:08:23"
		}
	]
}
```

#### 2.2.11物模型方法修改         

POST 请求接口
>/api/equipment/model/service/update   

请求参数

```json
{
    "id": "78901",
    "iotModelId": "123",
    "serviceCode": "grActivePowerSetPointValue",
    "serviceName": "功率设定值",
    "serviceType":146,
    "porder":1,
    "revision": 1,
    "updatedBy": "admin",
    "updatedTime": "2024-06-27 15:08:23"
}
```

返回报文

```json
{
	"code": 200,
	"msg": "更新成功",
	"success": true
}
```

#### 2.2.12物模型方法删除         

POST 请求接口
>/api/equipment/model/service/delete 

请求参数

```json
{
    "id": "78901"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述   |
| ------ | -------- | ---- | ------ |
| id     | 字符串   | No   | 主键ID |

返回报文

```json
{
	"code": 200,
	"msg": "删除成功",
	"success": true
}
```

#### 2.2.13 Excel导出物模型属性和方法

POST 请求接口

> /api/equipment/model/export

请求参数

```json
{
    "id": "123"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述     |
| ------ | -------- | ---- | -------- |
| id     | 字符串   | No   | 物模型ID |

返回 Excel文件，分成两个Sheet页，第一个sheet页是属性，第二个sheet页是方法，按【porder】排序显示



#### 2.2.14 Excel导入物模型属性和方法

Excel导入

### 2.3 设备台账相关接口

#### 2.3.1 设备不分页查询

POST请求接口 

> /api/equipment/list

请求参数

```json
{
    "orgId":"1",
    "parentEquipmentId":"2",
    "objectType":"10001"
}
```

参数说明

| 参数名            | 参数类型 | 可选 | 描述       |
| ----------------- | -------- | ---- | ---------- |
| orgId             | 字符串   | Yes  | 所属机构ID |
| parentEquipmentId | 字符串   | Yes  | 上级设备ID |
| objectType        | 字符串   | No   | 设备类型   |

返回报文

```json
{
	"code": 200,
	"msg": "操作成功",
	"success": true,
	"data": [
		{
			"id": "2017011807",
			"objectType": "10001",
			"code": "Station01",
			"name": "某某风电场",
			"madeinfactory": "生产厂家",
			"model": "规格型号",
			"location": "徐庄软件园",
			"longitude": 46.12345,
			"latitude": 137.01678,
			"installDate": "2024-06-27 15:08:23",
			"remarks": null,
			"orgId": "101",
			"parentEquipmentId": null,
			"iotModelId": "45678",
			"revision": 1,
			"createdBy": "admin",
			"createdTime": "2024-06-27 15:08:23",
			"updatedBy": "admin",
			"updatedTime": "2024-06-27 15:08:23"
		}
	]
}
```



#### 2.3.2 设备分页查询   

> /api/equipment/query   





#### 2.3.3 设备新增   

> /api/equipment/add    



#### 2.3.4 设备修改   

> /api/equipment/update 



#### 2.3.5 设备删除     

> /api/equipment/delete 



#### 2.3.6 Excel导出设备清单

> /api/equipment/export



#### 2.3.7 Excel导入设备清单

> /api/equipment/import
