# 权限模块

# API接口一览表

| 接口分类  | 接口描述              | API接口                             | 权限 |
|:-----:|:------------------|:----------------------------------|-|
| 系统登录 | 1.1、获取验证码         | /api/auth/captchaImage            | |
| 系统登录  | 1.2、系统登录          | /api/auth/login                   | |
| 系统登录  | 1.3、退出登录          | /api/auth/logout                  | |
| 系统登录  | 1.4、修改密码          | /api/auth/password/changePassword | |
| 菜单管理 | 2.1、新增菜单          | /api/menus/add                    | SYS_AUTHORITY_ID_ADMIN |
| 菜单管理 | 2.2、查询菜单          | /api/menus/query                  | |
| 菜单管理 | 2.3、更新菜单          | /api/menus/update                 |SYS_AUTHORITY_ID_ADMIN |
| 菜单管理 | 2.4、删除菜单          | /api/menus/delete                 |SYS_AUTHORITY_ID_ADMIN |
| 菜单管理 | 2.5、获取所有菜单信息      | /api/menus/list                   | |
| 菜单管理 | 2.6、查询登录账号所绑定的菜单树 | /api/menus/tree                   | |
| 公司机构 | 3.1、公司机构查询        | /api/org/query                    | |
| 公司机构 | 3.2、添加机构信息        | /api/org/add                      |SYS_AUTHORITY_ID_ADMIN |
| 公司机构 | 3.3、修改机构信息        | /api/org/update                   |SYS_AUTHORITY_ID_ADMIN |
| 公司机构 | 3.4、删除指定机构        | /api/org/delete                   | SYS_AUTHORITY_ID_ADMIN|
| 公司机构 | 3.5、获取所有的公司机构     | /api/org/list                     | |
| 职员操作 | 4.1、职员查询          | /api/user/query                   | |
| 职员操作 | 4.2、职员创建          | /api/user/add                     |SYS_AUTHORITY_ID_ADMIN |
| 职员操作 | 4.3、职员修改          | /api/user/update                  |SYS_AUTHORITY_ID_ADMIN |
| 职员操作 | 4.4、职员删除          | /api/user/delete                  |SYS_AUTHORITY_ID_ADMIN |
| 职员操作 | 4.5、根据id更新职员信息    | /api/user/updateById              | |
| 系统角色 | 5.1、系统角色查询        | /api/role/query                   | |
| 系统角色 | 5.2、系统角色新增        | /api/role/add                  |SYS_AUTHORITY_ID_ADMIN |
| 系统角色 | 5.3、系统角色删除      | /api/role/delete                     | SYS_AUTHORITY_ID_ADMIN|
| 系统角色 | 5.4、系统角色更新        | /api/role/update                  | SYS_AUTHORITY_ID_ADMIN|
| 系统角色 | 5.5、根据角色id获取角色权限信息        | /api/role/getAuthorityById        | |
| 系统权限 | 6.1、获取所有权限      | /api/authority/query        | |

## 1.1、验证码获取
> /api/auth/captchaImage


入参示例

无入参

调用成功返回示例
```json
{
  "code": 200,
  "msg": "操作成功",
  "success": true,
  "data": {
    "img": "",
    "key": "9007a0158f7c4635b4e6e577de7406e0"
  }
}
```
调用成功返回描述

| 变量名               | 变量类型   | 可为NULL | 描述         |
| -------------------- |--------| -------- |------------|
| img                | String | No       | 图片base64编码 |
| key                | String | No       | 验证码唯一标志    |

## 1.2、系统登录

使用用户名和密码，验证码和验证码的唯一标识登录系统，POST请求

> /api/auth/login

入参示例

```json
{
  "userName":"test",
  "password":"test123",
  "key":"ef4a4e7230a14e7ebbb657c135be2945",
  "keep":true,
  "code":"4OEE"
}
```

入参描述

| 参数名   | 参数类型    | 可选 | 描述   |
| -------- |---------| ---- |------|
| userName | String  | no   | 用户名  |
| password | String  | no   | 用户密码 |
| code | String  | no   | 验证码  |
| key | String  | no   | 唯一标志 |
| keep | boolean | no   | 是否记住 |

调用成功返回示例

```json
{
  "code": 200,
  "success": true,
  "data": {
    "sysUser": {
      "id": "73218693257382912",
      "account": "admin",
      "userName": "管理员",
      "orgId": "1",
      "authorities": [
        103,
        101,
        102
      ]
    },
    "refreshToken": "966333eee8b74f83b04cbd4d2e57695e",
    "token": "3090c84d828c402a86d00c0d43bb3783"
  },
  "msg": "操作成功"
}
```

调用成功返回描述

| 变量名               | 变量类型   | 可为NULL | 描述        |
| -------------------- |--------| -------- |-----------|
| token                | String | No       | 令牌(未加密)   |
| refreshToken                | String | No       | 刷新令牌(未加密) |
| sysUser                | String | No       | 用户信息      |

sysUser描述

| 变量名                 | 变量类型   | 可为NULL | 描述     |
|---------------------|--------| -------- |--------|
| id                  | String | No       | 主键id   |
| account             | String | No       | 账户名称   |
| userName             | String | No       | 用户名称   |
| orgId             | String | No       | 组织机构id |
| authorities             | List   | No       | 权限id列表 |


## 1.3、退出登录

注销令牌退出登录，POST请求

> /api/auth/logout

无入参

调用成功返回示例

```json
{
   "code":200,
   "data": null,
   "msg":"令牌已注销"
}
```

## 1.4、修改密码

修改登录密码，POST请求

> /api/auth/changePassword

入参示例

```json
{
  "id":"1489",
  "oldPassword":"test123",
  "newPassword":"test123456"
}
```

入参描述

| 参数名      | 参数类型 | 可选 | 描述   |
| ----------- | -------- | ---- | ------ |
| oldPassword | String   | NO   | 旧密码 |
| newPassword | String   | NO   | 新密码 |
| id    | String   | NO   | 用户名 |

调用成功返回示例

```json
{
  "code": 200,
  "success": true,
  "msg": "密码修改成功"
}
```

# 2、菜单管理


## 2.1、新增菜单


新增菜单接口，POST请求

> /api/menus/add

入参定义

```json

{
  "menuName": "菜单1",
  "menuOrder": 1,
  "menuIcon": "icon1",
  "funType": 1,
  "funParam": "param",
  "authorityId": "123",
  "parentMenuId": "0",
  "revision": 1
}
```
入参描述

| 参数名      | 参数类型    | 可选 | 描述     |
| ----------- |---------| ---- |--------|
| menuName        | String  | YES  | 菜单名称   |
| menuOrder | Integer | YES  | 菜单排列顺序 |
| menuIcon    | String  | YES  | 菜单图标名称 |
| funType        | Integer | YES  | 菜单操作类型 |
| funParam      | String  | YES  | 菜单操作参数 |
| authorityId      | Long    | YES  | 权限ID   |
| parentMenuId      | Long  | YES  | 上级菜单ID |
| revision      | Integer  | YES  | 乐观锁    |

调用成功返回示例

```json
{
	"code": 200,
	"msg": "操作成功",
    "success": true,
	"data": {
		"id": "123",
		"menuName": "菜单1",
		"menuOrder": 1,
		"menuIcon": "icon1",
		"funType": 1,
		"funParam": "param",
		"authorityId": "123",
		"parentMenuId": "0",
		"revision": 1,
		"createdBy": "aaa",
		"createdTime": 123456,
		"updatedBy": "aaa",
		"updatedTime": 12345
	}
}
```

## 2.2、查询菜单


查询菜单接口，分页查询，POST请求  

> /api/menus/query


入参定义

```json
{
  "parentMenuId": "0",
  "pageSize": 1,
  "pageNum": 1
}
```

入参描述

| 参数名      | 参数类型    | 可选 | 描述     |
| ----------- |---------| ---- |--------|
| parentMenuId      | Long  | YES  | 上级菜单ID |
| pageSize      | Integer  | YES  | 分页大小   |
| pageNum      | Integer  | YES  | 当前页数   |


调用成功返回示例

```json
{
  "total": 9,
  "rows": [
    {
      "createdBy": "aaa",
      "createdTime": "2024-06-27 07:08:23",
      "updatedBy": "aaa",
      "updatedTime": "2024-06-27 08:38:16",
      "revision": 2,
      "id": "73261935099379712",
      "menuName": "首页",
      "menuOrder": 0,
      "menuIcon": "el-icon-HomeFilled",
      "funType": 1,
      "funParam": "/dashboard.vue",
      "parentMenuId": 1
    }
  ],
  "code": 200,
  "msg": "查询成功"
}
```

## 2.3、更新菜单

更新菜单接口，post请求

> /api/menus/update


入参定义
```json
{
  "id": "123",
  "menuName": "菜单1",
  "menuOrder": 1,
  "menuIcon": "icon1",
  "funType": 1,
  "funParam": "param",
  "authorityId": "123",
  "parentMenuId": "0",
  "revision": 1
}
```

调用成功返回示例

```json
{
"code":"200",
"msg":"更新成功",
"success": true
}
```


## 2.4、删除菜单

删除菜单接口，post请求   

> /api/menus/delete

入参定义
```json
{  
  "id": "73261978251165698"
}
```
调用成功返回示例

```json
{
"code":"200",
"msg":"成功",
"success": true
}
```

## 2.5、获取所有菜单

获取所有菜单接口，post请求   
> /api/menus/list

入参定义

```json
{
  "parentMenuId": 0
}
```

调用成功返回示例

```json
{
	"code": 200,
	"msg": "操作成功",
    "success": true,
	"data": [
        {
		"id": "123",
		"menuName": "菜单1",
		"menuOrder": 1,
		"menuIcon": "icon1",
		"funType": 1,
		"funParam": "param",
		"authorityId": "123",
		"parentMenuId": "0",
		"revision": 1,
		"createdBy": "aaa",
		"createdTime": 123456,
		"updatedBy": "aaa",
		"updatedTime": 12345
	}
    ]
}
```

## 2.6、获取登录账号所绑定菜单

获取登录账号所绑定菜单接口   
> /api/menus/tree


入参定义

无入参


调用成功返回示例

```json
{
  "code": 200,
  "success": true,
  "data": {
    "id": "1",
    "menuName": "系统菜单",
    "menuOrder": 0,
    "funType": 1,
    "funParam": "",
    "parentMenuId": "0",
    "revision": 1,
    "createdBy": "aaa",
    "createdTime": "2024-06-27 15:08:23",
    "updatedBy": "aaa",
    "updatedTime": "2024-06-27 15:10:14",
    "children": [
      {
        "id": "73261935099379712",
        "menuName": "首页",
        "menuOrder": 0,
        "menuIcon": "el-icon-HomeFilled",
        "funType": 1,
        "funParam": "/dashboard.vue",
        "parentMenuId": "1",
        "revision": 2,
        "createdBy": "aaa",
        "createdTime": "2024-06-27 15:08:23",
        "updatedBy": "aaa",
        "updatedTime": "2024-06-27 16:38:16",
        "children": []
      },
      {
        "id": "73264464182902784",
        "menuName": "设备管理",
        "menuOrder": 1,
        "menuIcon": "fa fa-wrench",
        "funType": 1,
        "funParam": "",
        "parentMenuId": "1",
        "revision": 1,
        "createdBy": "aaa",
        "createdTime": "2024-06-27 17:49:11",
        "updatedBy": "aaa",
        "updatedTime": "2024-06-27 17:49:11",
        "children": []
      },
      {
        "id": "73261978251165696",
        "menuName": "系统管理",
        "menuOrder": 3,
        "menuIcon": "el-icon-Setting",
        "funType": 1,
        "funParam": "",
        "authorityId": 101,
        "parentMenuId": "1",
        "revision": 3,
        "createdBy": "aaa",
        "createdTime": "2024-06-27 15:11:08",
        "updatedBy": "aaa",
        "updatedTime": "2024-06-28 08:48:07",
        "children": [
          {
            "id": "73264252690890752",
            "menuName": "机构管理",
            "menuOrder": 1,
            "menuIcon": "el-icon-Briefcase",
            "funType": 1,
            "funParam": "/InstitutionalManagement/InstitutionalManagement.vue",
            "parentMenuId": "73261978251165696",
            "revision": 2,
            "createdBy": "aaa",
            "createdTime": "2024-06-27 17:35:44",
            "updatedBy": "aaa",
            "updatedTime": "2024-06-28 08:46:01",
            "children": []
          },
          {
            "id": "73263970159165440",
            "menuName": "用户配置",
            "menuOrder": 2,
            "menuIcon": "fa fa-user",
            "funType": 1,
            "funParam": "/auth/userManagement/index.vue",
            "parentMenuId": "73261978251165696",
            "revision": 2,
            "createdBy": "aaa",
            "createdTime": "2024-06-27 17:17:46",
            "updatedBy": "aaa",
            "updatedTime": "2024-06-27 17:19:57",
            "children": []
          },
          {
            "id": "73263768646451200",
            "menuName": "角色配置",
            "menuOrder": 3,
            "menuIcon": "el-icon-Avatar",
            "funType": 1,
            "funParam": "/RoleManagement/RoleManagement.vue",
            "parentMenuId": "73261978251165696",
            "revision": 5,
            "createdBy": "aaa",
            "createdTime": "2024-06-27 17:04:57",
            "updatedBy": "aaa",
            "updatedTime": "2024-06-28 08:46:54",
            "children": []
          },
          {
            "id": "73263965539926016",
            "menuName": "菜单配置",
            "menuOrder": 4,
            "menuIcon": "fa fa-th-list",
            "funType": 1,
            "funParam": "/auth/menuManagement/index.vue",
            "authorityId": 101,
            "parentMenuId": "73261978251165696",
            "revision": 5,
            "createdBy": "aaa",
            "createdTime": "2024-06-27 17:17:29",
            "updatedBy": "aaa",
            "updatedTime": "2024-06-28 08:46:58",
            "children": []
          },
          {
            "id": "73263976546828288",
            "menuName": "物模型配置",
            "menuOrder": 5,
            "menuIcon": "fa fa-print",
            "funType": 1,
            "funParam": "",
            "parentMenuId": "73261978251165696",
            "revision": 2,
            "createdBy": "aaa",
            "createdTime": "2024-06-27 17:18:11",
            "updatedBy": "aaa",
            "updatedTime": "2024-06-28 08:47:05",
            "children": []
          }
        ]
      }
    ]
  },
  "msg": "操作成功"
}
```

返回参数描述

| 参数名          | 参数类型    | 可选 | 描述     |
|--------------|---------| ---- |--------|
| id           | String  | YES  | 主键ID   |
| menuName     | String  | YES  | 菜单名称   |
| menuOrder    | Integer | YES  | 菜单排列顺序 |
| menuIcon     | String  | YES  | 菜单图标名称 |
| funType      | Integer | YES  | 菜单操作类型 |
| funParam     | String  | YES  | 菜单操作参数 |
| authorityId  | Long    | YES  | 权限ID   |
| parentMenuId | Long  | YES  | 上级菜单ID |
| revision     | Integer  | YES  | 乐观锁    |
| createdBy   | String  | YES  | 创建人   |
| createdTime | String  | YES  | 创建时间 |
| updatedBy   | String  | YES  | 更新人   |
| updatedTime | String  | YES  | 更新时间 |
| children     | List    | YES  | 子菜单列表 |


[//]: # "!> 下面的文档有待确认"

# 3、公司机构

组织机构模块提供的API包括机构查询、添加、修改等功能。

## 3.1、公司机构查询

提供获取所有机构信息的功能，POST方式

> /api/org/query

入参示例

```json
{
  "name":"12",
  "parentOrgId":"1",
  "province":"江苏",
  "city":"南京",
  "county":"玄武区",
"pageSize": 1,
"pageNum": 1
}
```

入参描述

| 参数名      | 参数类型    | 可选 | 描述                  |
| ----------- |---------| ---- |---------------------|
| name        | String  | YES  | 机构名称，当名称为空时查询所有机构数据 |
| parentOrgId | String  | YES  | 上级机构ID              |
| province    | String  | YES  | 省                   |
| city        | String  | YES  | 城市                  |
| county      | String  | YES  | 区县                  |
| pageSize      | Integer | YES  | 分页大小                |
| pageNum      | Integer  | YES  | 当前页数                  |

调用成功返回示例

```json
{
  "total": 4,
  "rows": [
    {
      "id": "73280038685114368",
      "name": "test",
      "mrid": "test",
      "province": "山西省",
      "city": "绛县",
      "county": "运城市",
      "address": "test",
      "contactPhone": "13045088888",
      "remarks": "test",
      "aliasName": "test",
      "parentOrgId": "1",
      "parentOrgName": "某风电场",
      "revision": 1
    }
  ],
  "code": 200,
  "msg": "查询成功"
}
```

调用成功返回描述

| 变量名       | 变量类型 | 可为NULL | 描述       |
| ------------ | -------- | -------- | ---------- |
| id           | Integer  | No       | id         |
| mrid         | String   | No       | 编码       |
| name         | String   | No       | 名称       |
| aliasName    | String   | No       | 简称/别名  |
| province     | String   | No       | 省         |
| city         | String   | No       | 城市       |
| county       | String   | No       | 区县       |
| address      | String   | No       | 详细地址   |
| contactPhone | String   | No       | 联系电话   |
| remarks      | String   | No       | 备注       |
| parentOrgId  | Long     | No       | 上级机构ID |
| parentOrgName | String   | No       | 上级机构名称 |



## 3.2、新增机构信息

根据添加的机构信息创建机构，POST方式

>/api/org/add

入参示例

```json
 {
      "name": "test",
      "mrid": "test",
      "province": "山西省",
      "city": "绛县",
      "county": "运城市",
      "address": "test",
      "contactPhone": "13045088888",
      "remarks": "test",
      "aliasName": "test",
      "parentOrgId": "1",
      "revision": 1
}
   
```

入参描述

| 变量名       | 变量类型 | 可为NULL | 描述       |
| ------------ | -------- | -------- | ---------- |
| mrid         | String   | No       | 编码       |
| name         | String   | No       | 名称       |
| aliasName    | String   | No       | 简称/别名  |
| province     | String   | No       | 省         |
| city         | String   | No       | 城市       |
| county       | String   | No       | 区县       |
| address      | String   | No       | 详细地址   |
| contactPhone | String   | No       | 联系电话   |
| remarks      | String   | No       | 备注       |
| parentOrgId  | Long     | No       | 上级机构ID |

调用成功返回示例

```json
{
"code":"200",
"msg":"添加成功",
"success": true
}
```



## 3.3、修改机构信息

修改机构信息接口，POST方式

>  /api/org/update

入参示例

```json
 {
      "id":"xxx",
      "mrid": "xxx",
      "name": "xxx",
      "aliasName":"xxx",
      "province": "xxx",
      "city": "xxx",
      "county": "xxx",
      "address": "xxx",
      "contactPhone":"xxx",
      "remarks":"xxx",
      "parentOrgId":"xxxx"
   }
```

入参描述

| 变量名       | 变量类型 | 可为NULL | 描述       |
| ------------ | -------- | -------- | ---------- |
| id           | BIGINT   | No       | 机构ID     |
| mrid         | String   | No       | 编码       |
| name         | String   | No       | 名称       |
| aliasName    | String   | No       | 简称/别名  |
| province     | String   | No       | 省         |
| city         | String   | No       | 城市       |
| county       | String   | No       | 区县       |
| address      | String   | No       | 详细地址   |
| contactPhone | String   | No       | 联系电话   |
| remarks      | String   | No       | 备注       |
| parentOrgId  | Long     | No       | 上级机构ID |



调用成功返回示例

```json
{
"code":"200",
"msg":"修改成功",
"success": true
}
```


## 3.4、删除指定机构

根据提供的机构ID,删除机构信息，POST方式

>/api/org/delete

入参示例

```json
{
       "id":"111"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述             |
| ------ | -------- | ---- | ---------------- |
| id     | Long     | No   | 要删除的机构主键 |

调用成功返回示例

```json
{
"code":"200",
"msg":"修改成功",
"success": true
}
```

## 3.5、获取机构列表
根据获取机构列表，POST方式

>/api/org/list

入参示例

```json
{
       "parentOrgId":111
}

```

入参描述

| 参数名 | 参数类型    | 可选 | 描述     |
| ------ |---------| ---- |--------|
| parentOrgId     | Long    | No   | 机构id   |

调用成功返回示例

```json
{
  "code": 200,
  "success": true,
  "data": [
    {
      "id": "2",
      "name": "测试子公司",
      "mrid": "456",
      "province": "江苏",
      "city": "南京",
      "county": "玄武",
      "address": "测试地址1",
      "contactPhone": "555889",
      "remarks": "测试",
      "parentOrgId": 1,
      "revision": 1
    }
  ],
  "msg": "操作成功"
}
```

# 4、职员用户

职员模块提供的API包括职员查询、添加、修改等功能。

## 4.1、职员信息查询
查询职员信息接口,POST方式。

>/api/user/query

入参示例

```json
{
"userName":"测试",
"orgId":"1",
"pageSize": 1,
"pageNum": 1
}
```

入参描述

| 参数名      | 参数类型 | 可选  | 描述                        |
|:---------| :------: | :---: |:--------------------------|
| userName |  String  |  Yes  | 模糊查询职员名称，当职员名称为空时查询所有职员信息 |
| orgId    |  BIGINT  |  Yes  | 所属机构ID                    |
| pageSize |  Integer  |  Yes  | 每页显示条数                  |
| pageNum  |  Integer  |  Yes  | 当前页码                    |

调用成功返回示例

```json
{
  "total": 1,
  "rows": [
    {
      "id": 73238484643741696,
      "account": "test1",
      "userName": "测试1",
      "revision": 1,
      "phone": "1231212",
      "email": "测试",
      "orgId": 1,
      "roleList": [
        {
          "id": 73220290639036416,
          "roleCode": "1212",
          "roleName": "测试角色1",
          "revision": 1
        },
        {
          "id": 73212978522226688,
          "roleCode": "0011",
          "roleName": "测试角色",
          "revision": 1
        }
      ]
    }
  ],
  "code": 200,
  "msg": "查询成功"
}
```

| 变量名   | 变量类型   | 可为NULL | 描述         |
| -------- |--------| -------- |------------|
| id       | BIGINT | No       | 主键(雪花算法生成) |
| account  | String | No       | 登录账号       |
| userName | String | No       | 职员名称       |
| email    | String | No       | 职员邮箱       |
| phone    | String | No       | 职员联系电话     |
| orgId    | BIGINT | No       | 所属机构ID     |
| roleList    | List   | No       | 角色集合       |

##  4.2、职员创建

新增职员信息，POST方式。

>/api/user/add

入参示例

```json
{
      "account": "test1",
      "password": "123456789",
      "userName": "测试",
      "email":"1204561456@qq.com",
      "phone":"123456789",
      "orgId":"1",
  "headImage": "Aim",
      "roleList":[73220290639036416,73212978522226688]
}
```

入参描述

| 变量名   | 变量类型   | 可为NULL | 描述     |
| -------- |--------| -------- |--------|
| account  | String | No       | 登录账号   |
| password | String | No       | 加密后的密码 |
| userName | String | No       | 职员名称   |
| email    | String | No       | 职员邮箱   |
| phone    | String | No       | 职员联系电话 |
| orgId    | BIGINT | No       | 所属机构ID |
| headImage    | String   | No       | 头像     |
| roleList    | List   | No       | 角色id集合 |

调用成功返回示例

```json
{
  "code": 200,
  "success": true,
  "data": {
    "account": "test1",
    "roleList": [
      73220290639036416,
      73212978522226688
    ]
  },
  "msg": "操作成功"
}
```



## 4.3、职员信息修改

根据提供的职员id,修改职员信息，POST方式。

>/api/user/update



```json
{
      "id":"123",
      "account": "test",
      "userName": "测试1",
      "email":"1454478595@qq.com",
      "phone":"15154788429",
      "orgId":"1",
  "headImage":"Aim",
  "roleList":[73220290639036416,73212978522226688]
}
```

入参描述

| 变量名   | 变量类型 | 可为NULL | 描述               |
| -------- | -------- | -------- | ------------------ |
| id       | BIGINT   | No       | 主键(雪花算法生成) |
| account  | String   | No       | 登录账号           |
| userName | String   | No       | 职员名称           |
| email    | String   | No       | 职员邮箱           |
| phone    | String   | No       | 职员联系电话       |
| orgId    | BIGINT   | No       | 所属机构ID         |
| headImage    | String   | No       | 头像|
| roleList    | List   | No       | 角色id集合 |

调用成功返回示例

```json
{
  "code": 200,
  "success": true,
  "msg": "操作成功"
}
```

## 4.4、职员删除

根据提供的职员id,删除职员信息，POST方式。

> /api/user/delete

入参示例

```json
{
       "id":"123"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述           |
| ------ | -------- | ---- | -------------- |
| id     | BIGINT   | No   | 要删除的职员Id |

调用成功返回示例

```json
{
  "code": 200,
  "success": true,
  "msg": "操作成功"
}
```

## 4.5、根据id更新职员信息（登录账号修改自身信息）

根据提供的职员id修改登录的账号的职员信息，POST方式。

> /api/user/updateById

入参示例

```json
{
  "id":"123",
  "account": "test",
  "userName": "测试1",
  "email":"1454478595@qq.com",
  "phone":"15154788429",
  "headImage":"Aim"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述           |
| ------ | -------- | ---- | -------------- |
| id     | BIGINT   | No   | 要删除的职员Id |
| account  | String   | No       | 登录账号           |
| userName | String   | No       | 职员名称           |
| email    | String   | No       | 职员邮箱           |
| phone    | String   | No       | 职员联系电话       |
| headImage    | String   | No       | 头像|

调用成功返回示例

```json
{
  "code": 200,
  "success": true,
  "msg": "操作成功"
}
```

#  5、角色维护

## 5.1 、角色信息查询

查询系统角色，POST方式

> /api/role/query

入参示例

```json
{
  "roleName": "运维",
  "pageSize": 10,
  "pageNum": 1
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述   |
| ------ | -------- | ---- |------|
| roleName     | String   | No   | 角色名称 |
| pageSize  | String   | No       | 分页大小 |
| pageNum | String   | No       | 当前页数 |

调用成功返回示例

```json
{
  "total": 1,
  "rows": [
    {
      "id": "73281743167422464",
      "roleCode": "deviceMgr",
      "roleName": "设备运维",
      "revision": 1,
      "list": [
        {
          "id": "102",
          "authorityCode": "SYS_AUTHORITY_ID_DEVICE_MGR",
          "authorityName": "设备台账维护权限"
        }
      ]
    }
  ],
  "code": 200,
  "msg": "查询成功"
}
```
返回描述

| 变量名        | 变量类型 | 可为NULL | 描述     |
| ------------- | -------- | -------- | -------- |
| id            | BIGINT   | NO       | 主键id   |
| roleCode | string   | NO       | 权限编码 |
| roleName | string   | NO       | 权限名称 |
| list | List   | NO       | 权限集合 |

list描述

| 变量名        | 变量类型 | 可为NULL | 描述     |
| ------------- | -------- | -------- | -------- |
| id            | BIGINT   | NO       | 主键id   |
| authorityCode | string   | NO       | 权限编码 |
| authorityName | string   | NO       | 权限名称 |

##  5.2、系统角色新增
新增角色，POST方式

> /api/role/add

入参示例

```json
{
  "roleName":"测试角色",
  "roleCode":"001",
  "authList":[101,102,103]
}
```

入参描述

| 变量名        | 变量类型 | 可为NULL | 描述     |
| ------------- | -------- | -------- |--------|
| roleName      | String   | No       | 角色名称   |
| roleCode      | String   | No       | 角色编码   |
| authList      | List     | No       | 权限id集合 |

调用成功返回示例

```json
{
  "code": 200,
  "success": true,
  "data": {
    "roleName": "测试",
    "roleCode": "160",
    "authList": [
      102
    ]
  },
  "msg": "操作成功"
}
```

| 变量名   | 变量类型 | 可为NULL | 描述     |
| -------- | -------- | -------- | -------- |
| roleCode | string   | No       | 角色编码 |
| roleName | string   | No       | 角色名称 |
| authList | List     | No       | 权限id集合 |

## 5.3 、系统角色删除

根据提供的ID,删除系统角色，POST方式

> /api/role/delete

入参示例

```json
{
  "id": "123"
}
```

入参描述

| 变量名   | 变量类型 | 可为NULL | 描述     |
| -------- | -------- | -------- | -------- |
| id       | BIGINT   | No       | 角色id   |

调用成功返回示例

```json
{
  "code": 200,
  "success": true,
  "msg": "操作成功"
}
```

## 5.4 、系统角色更新

更新对应的角色信息，POST方式

> /api/role/update

入参示例

```json
{
  "id": "73336048225615872",
    "roleName":"测试角色",
    "roleCode":"001",
    "authList":[101,102,103]
}
```

入参描述

| 变量名   | 变量类型 | 可为NULL | 描述     |
| -------- | -------- | -------- | -------- |
| id       | BIGINT   | No       | 角色id   |
| roleName | string   | No       | 角色名称 |
| roleCode | string   | No       | 角色编码 |
| authList | List     | No       | 权限id集合 |

调用成功返回示例

```json
{
  "code": 200,
  "success": true,
  "data": {
    "id": "73336048225615872",
    "roleName": "测试",
    "roleCode": "1161",
    "authList": [
      102
    ]
  },
  "msg": "操作成功"
}
```
## 5.5 、根据角色id获取角色权限信息
根据角色id获取角色权限信息 ，POST方式
> /api/role/queryAuthorityById

入参示例


```json
{
"roleId":"73336048225615872"
}
```

调用成功返回示例

```json
{
"code": 200,
"success": true,
"data": [
{
"id": "102",
"authorityCode": "equipmentLedgerManagement",
"authorityName": "设备台账维护权限",
"revision": 1
}
],
"msg": "操作成功"
}
```

调用成功返回

| 变量名   | 变量类型 | 可为NULL | 描述   |
| -------- | -------- | -------- |------|
| id       | BIGINT   | No       | 主键id |
| authorityCode | string   | No       | 权限编码 |
| authorityName | string   | No       | 权限名称 |


#  6、系统权限

## 6.1 、获取所有权限

查询系统所有的权限接口，POST方式

> /api/authority/query

入参示例

无入参

调用成功返回示例

```json
{
  "code": 200,
  "success": true,
  "data": [
    {
      "revision": 1,
      "id": "102",
      "authorityCode": "SYS_AUTHORITY_ID_DEVICE_MGR",
      "authorityName": "设备台账维护权限"
    },
    {
      "revision": 1,
      "id": "103",
      "authorityCode": "SYS_AUTHORITY_ID_DEVICE_VIEW",
      "authorityName": "设备台账浏览权限"
    },
    {
      "revision": 1,
      "id": "101",
      "authorityCode": "SYS_AUTHORITY_ID_ADMIN",
      "authorityName": "系统管理权限"
    }
  ],
  "msg": "操作成功"
}

```


调用成功返回

| 变量名   | 变量类型 | 可为NULL | 描述   |
| -------- | -------- | -------- |------|
| id       | BIGINT   | No       | 主键id |
| authorityCode | string   | No       | 权限编码 |
| authorityName | string   | No       | 权限名称 |
