export type getDataType = {
    name?: string | null
    parentOrgId?: string | number
    province?: string
    city?: string
    county?: string
    pageSize?: number
    pageNum?: number
}
export type getDataReturnType<T extends any> = Promise<{
    code: number
    msg: string
    rows: T[]
    total: number
}>

export enum addDataEnum {
    mrid = '机构编码',
    name = '机构名称',
    aliasName = '机构简称',
    province = '机构省份',
    city = '机构城市',
    county = '机构区县',
    address = '详细地址',
    contactPhone = '联系电话',
    remarks = '备注',
    parentOrgId = '上级机构',
    parentOrgName = '上级机构名称',
}
export type allEnumType = keyof typeof addDataEnum

export type addDataEnumKeyJointType = Exclude<allEnumType, 'parentOrgName'>

export type formItemListType<T extends addDataEnumKeyJointType> = {
    type: 'input' | 'select' | 'custom'
    prop: T
    label: (typeof addDataEnum)[T]
    placeholder: `请输入${(typeof addDataEnum)[T]}` | `请选择${(typeof addDataEnum)[T]}`
    rules?:
        | [{ required: boolean; message: `请输入${(typeof addDataEnum)[T]}` | `请选择${(typeof addDataEnum)[T]}`; trigger: 'blur' | 'change' }]
        | [{ required?: boolean; validator: (rule: any, value: any, callback: any) => void; trigger: 'blur' | 'change' }]
}
export type selectDataType = {
    label: string
    value: string
    children?: selectDataType[]
}
export type addDataType = {
    mrid: string
    name: string
    aliasName: string
    province: string
    city: string
    county: string
    address: string
    contactPhone: string
    remarks: string
    parentOrgId: number | null
    revision: number
}

export type changeDataType = {
    id: string
} & addDataType

export type operateDataReturnType<T = any> = Promise<{
    code: number
    msg: string
    success: boolean
    data?: T
}>

export type delDataType = {
    id: string
}
export type getTreeDataType = {
    parentOrgId: number | string | null
}

export type tableColumnType<T extends allEnumType> = {
    key: string
    prop: T
    label: (typeof addDataEnum)[T]
    fixed?: boolean
    align?: 'left' | 'center' | 'right'
}

export type getTreeDataReturnType = {
    address: string
    children?: getTreeDataReturnType[]
    city: string
    contactPhone: string
    county: string
    id: string
    mrid: string
    name: string
    parentOrgId: number
    parentOrgName: string
    province: string
    remarks: string
    revision: number
    isLeaf?: boolean
}
