export enum formDataEnum {
    id = '系统角色id',
    authList = '角色权限',
    roleName = '角色名称',
    roleCode = '角色编码',
}

export type formDataType = {
    id: string
    authList: string[]
    roleName: string
    roleCode: string
}

export type formDataEnumKeyJointType = keyof typeof formDataEnum

export type formColumnListType<T extends formDataEnumKeyJointType> = {
    key?: string
    label: (typeof formDataEnum)[T]
    prop: T
    type: 'input' | 'custom'
    fixed?: boolean
    align?: 'center' | 'left' | 'right'
    rule:
        | [{ required: true; message: string; trigger: 'blur' | 'change' }]
        | [{ validator: (rule: any, value: any, callback: any) => void; trigger: 'blur' | 'change' }]
}

export enum tableDataEnum {
    id = '系统角色id',
    listName = '角色权限',
    roleName = '角色名称',
    roleCode = '角色编码',
    authList = '角色权限编码',
}

export type tableDataColumnType = {
    id: string
    authList: string[]
    roleName: string
    roleCode: string
    listName: string
}
export type tableDataColumnTypeJointType = keyof typeof tableDataEnum

export type tableDataType<T extends authorityDataListType> = {
    id: string
    revision: number
    roleCode: number
    roleName: string
    listName: T['authorityName']
    authList: T['id'][]
}

export type tableColumnType<T extends tableDataColumnTypeJointType> = {
    key: string
    prop: T
    label: (typeof tableDataEnum)[T]
    fixed?: boolean
    align?: 'left' | 'center' | 'right'
}

export type authorityDataListType = {
    authorityCode: string
    authorityName: string
    id: string
    revision: number
}

export type roleListReturnType<T> = Promise<{
    code: number
    msg: string
    rows: T[]
    total: number
}>
export type roleListReturnDataType<T> = Promise<{
    code: number
    msg: string
    data: T[]
    success: boolean
}>
export type getDataType = {
    roleName: string
}

export type getDataReturnType = {
    id: string
    revision: number
    roleCode: number
    roleName: string
    list: authorityDataListType[]
}

export type changeDataType = Omit<formDataType, 'roleCode'>

export type changeDataReturnType = {
    authList: number[]
    id: string
    roleCode: string
    roleName: string
}
export type addDataType = Omit<formDataType, 'id'>

export type addDataReturnType = changeDataReturnType

export type delDataType = {
    id: string
}
